"""MSSDK 是基于 Python 的为麦思多维科技客户服务的专用 API 接口"""

"""
0.0.1: 发布测试版本 v0.0.1
0.0.2: 发布测试版本 v0.0.2
0.0.3: 发布测试版本 v0.0.3
0.0.4: 发布测试版本 v0.0.4
0.0.5: 发布测试版本 v0.0.5
0.0.6: 发布测试版本 v0.0.6
0.0.7: 发布测试版本 v0.0.7
0.0.8: 发布测试版本 v0.0.8
0.0.9: 发布测试版本 v0.0.9
0.0.10: 发布测试版本 v0.0.10
0.0.11: 发布测试版本 v0.0.11
0.0.12: 发布测试版本 v0.0.12
0.0.13: 发布测试版本 v0.0.13
0.0.14: 发布测试版本 v0.0.14
0.0.15: 发布测试版本 v0.0.15
0.0.16: 发布测试版本 v0.0.16
0.0.16: 发布测试版本 v0.0.16
0.0.17: 发布测试版本 v0.0.17
0.0.18: 发布测试版本 v0.0.18
0.0.19: 发布测试版本 v0.0.19
0.0.20: 发布测试版本 v0.0.20
0.0.21: 发布测试版本 v0.0.21
0.0.22: 发布测试版本 v0.0.22
0.0.23: 发布测试版本 v0.0.23
0.0.24: 发布测试版本 v0.0.24
0.0.25: 发布测试版本 v0.0.25
0.0.26: 发布测试版本 v0.0.26
0.0.27: 发布测试版本 v0.0.27
0.0.28: 发布测试版本 v0.0.28
0.0.29: 发布测试版本 v0.0.29
0.0.30: 发布测试版本 v0.0.30
0.0.31: 发布测试版本 v0.0.31
0.0.32: 发布测试版本 v0.0.32
0.0.33: 发布测试版本 v0.0.33
0.0.34: 发布测试版本 v0.0.34
0.0.35: 发布测试版本 v0.0.35
0.0.36: 发布测试版本 v0.0.36
0.0.37: 发布测试版本 v0.0.37
"""

__version__ = '0.0.37'
__author__ = 'mssdk'

import sys

if sys.version_info < (3, 7):
    print(f"mssdk {__version__} requires Python 3.7+ and 64 bit OS")
    sys.exit(1)

del sys

from mssdk.score.score import Score

score = Score

"""
东方财富-行业板块
"""
from mssdk.stock.stock_board_industry_em import (
    stock_board_industry_cons_em,
    stock_board_industry_hist_em,
    stock_board_industry_name_em,
)

"""
天天基金网-基金数据-规模变动
"""
from mssdk.fund.fund_scale_em import fund_scale_change_em, fund_hold_structure_em

"""
天天基金网-基金数据-分红送配
"""
from mssdk.fund.fund_fhsp_em import fund_cf_em, fund_fh_rank_em, fund_fh_em

"""
中国电竞价值排行榜
"""
from mssdk.other.other_game import club_rank_game, player_rank_game

"""
艺恩-艺人
"""
from mssdk.movie.artist_yien import online_value_artist, business_value_artist

"""
艺恩-视频放映
"""
from mssdk.movie.video_yien import video_variety_show, video_tv

"""
同花顺-数据中心-技术选股
"""
from mssdk.stock_feature.stock_technology_ths import (
    stock_rank_cxg_ths,
    stock_rank_cxd_ths,
    stock_rank_lxsz_ths,
    stock_rank_lxxd_ths,
    stock_rank_cxfl_ths,
    stock_rank_cxsl_ths,
    stock_rank_xstp_ths,
    stock_rank_xxtp_ths,
    stock_rank_ljqd_ths,
    stock_rank_ljqs_ths,
    stock_rank_xzjp_ths,
)

"""
沪深港通持股
"""
from mssdk.stock_feature.stock_em_hsgt import (
    stock_hsgt_individual_em,
    stock_hsgt_individual_detail_em,
)

"""
指数估值
"""
from mssdk.index.zh_stock_index_csindex import (
    index_value_hist_funddb,
    index_value_name_funddb,
)

"""
基金规模
"""
from mssdk.fund.fund_scale_sina import (
    fund_scale_open_sina,
    fund_scale_close_sina,
    fund_scale_structured_sina,
)

"""
巨潮资讯-数据中心-专题统计-基金报表
"""
from mssdk.fund.fund_report_cninfo import (
    fund_report_stock_cninfo,
    fund_report_industry_allocation_cninfo,
    fund_report_asset_allocation_cninfo,
)

"""
巨潮资讯-数据中心-专题统计-债券报表-债券发行
"""
from mssdk.bond.bond_issue_cninfo import (
    bond_treasure_issue_cninfo,
    bond_local_government_issue_cninfo,
    bond_corporate_issue_cninfo,
    bond_cov_issue_cninfo,
    bond_cov_stock_issue_cninfo,
)

"""
巨潮资讯-数据中心-专题统计-公司治理-股权质押
"""
from mssdk.stock.stock_cg_equity_mortgage import stock_cg_equity_mortgage_cninfo

"""
巨潮资讯-数据中心-专题统计-公司治理-公司诉讼
"""
from mssdk.stock.stock_cg_lawsuit import stock_cg_lawsuit_cninfo

"""
巨潮资讯-数据中心-专题统计-公司治理-对外担保
"""
from mssdk.stock.stock_cg_guarantee import stock_cg_guarantee_cninfo

"""
B 股
"""
from mssdk.stock.stock_zh_b_sina import (
    stock_zh_b_spot,
    stock_zh_b_daily,
    stock_zh_b_minute,
)

"""
期货手续费
"""
from mssdk.futures.futures_comm_qihuo import futures_comm_info

"""
实际控制人持股变动
"""
from mssdk.stock.stock_hold_control_cninfo import (
    stock_hold_control_cninfo,
    stock_hold_management_detail_cninfo,
)

"""
股东人数及持股集中度
"""
from mssdk.stock.stock_hold_num_cninfo import stock_hold_num_cninfo

"""
新股过会
"""
from mssdk.stock.stock_new_cninfo import stock_new_gh_cninfo, stock_new_ipo_cninfo

"""
个股分红
"""
from mssdk.stock.stock_dividents_cninfo import stock_dividents_cninfo

"""
行业市盈率
"""
from mssdk.stock.stock_industry_pe_cninfo import stock_industry_pe_ratio_cninfo

"""
投资评级
"""
from mssdk.stock.stock_rank_forecast import stock_rank_forecast_cninfo

"""
美股-知名美股
"""
from mssdk.stock.stock_us_famous import stock_us_famous_spot_em

"""
美股-粉单市场
"""
from mssdk.stock.stock_us_pink import stock_us_pink_spot_em

"""
REITs
"""
from mssdk.reits.reits_basic import reits_info_jsl, reits_realtime_em

"""
鸡蛋价格数据
"""
from mssdk.futures_derivative.futures_egg import (
    futures_egg_price_yearly,
    futures_egg_price_area,
    futures_egg_price,
)

"""
全部 A 股-等权重市盈率、中位数市盈率
全部 A 股-等权重、中位数市净率
"""
from mssdk.stock_feature.stock_ttm_lyr import stock_a_ttm_lyr
from mssdk.stock_feature.stock_all_pb import stock_a_all_pb

"""
奥运奖牌
"""
from mssdk.sport.sport_olympic import sport_olympic_hist

"""
宏观-加拿大
"""
from mssdk.economic.macro_canada import (
    macro_canada_cpi_monthly,
    macro_canada_core_cpi_monthly,
    macro_canada_bank_rate,
    macro_canada_core_cpi_yearly,
    macro_canada_cpi_yearly,
    macro_canada_gdp_monthly,
    macro_canada_new_house_rate,
    macro_canada_retail_rate_monthly,
    macro_canada_trade,
    macro_canada_unemployment_rate,
)

"""
猪肉价格信息
"""
from mssdk.futures_derivative.futures_pig import futures_pig_info, futures_pig_rank

"""
宏观-澳大利亚
"""
from mssdk.economic.macro_australia import (
    macro_australia_bank_rate,
    macro_australia_unemployment_rate,
    macro_australia_trade,
    macro_australia_cpi_quarterly,
    macro_australia_cpi_yearly,
    macro_australia_ppi_quarterly,
    macro_australia_retail_rate_monthly,
)

"""
融资融券-深圳
"""
from mssdk.stock_feature.stock_szse_margin import (
    stock_margin_underlying_info_szse,
    stock_margin_detail_szse,
    stock_margin_szse,
)

"""
英国-宏观
"""
from mssdk.economic.macro_uk import (
    macro_uk_gdp_yearly,
    macro_uk_gdp_quarterly,
    macro_uk_retail_yearly,
    macro_uk_rightmove_monthly,
    macro_uk_rightmove_yearly,
    macro_uk_unemployment_rate,
    macro_uk_halifax_monthly,
    macro_uk_bank_rate,
    macro_uk_core_cpi_monthly,
    macro_uk_core_cpi_yearly,
    macro_uk_cpi_monthly,
    macro_uk_cpi_yearly,
    macro_uk_halifax_yearly,
    macro_uk_retail_monthly,
    macro_uk_trade,
)

"""
日本-宏观
"""
from mssdk.economic.macro_japan import (
    macro_japan_bank_rate,
    macro_japan_core_cpi_yearly,
    macro_japan_cpi_yearly,
    macro_japan_head_indicator,
    macro_japan_unemployment_rate,
)

"""
瑞士-宏观
"""
from mssdk.economic.macro_swiss import (
    macro_swiss_trade,
    macro_swiss_svme,
    macro_swiss_cpi_yearly,
    macro_swiss_gbd_yearly,
    macro_swiss_gbd_bank_rate,
    macro_swiss_gdp_quarterly,
)

"""
东方财富-概念板块
"""
from mssdk.stock.stock_board_concept_em import (
    stock_board_concept_cons_em,
    stock_board_concept_hist_em,
    stock_board_concept_name_em,
)

"""
德国-经济指标
"""
from mssdk.economic.macro_germany import (
    macro_germany_gdp,
    macro_germany_ifo,
    macro_germany_cpi_monthly,
    macro_germany_retail_sale_monthly,
    macro_germany_trade_adjusted,
    macro_germany_retail_sale_yearly,
    macro_germany_cpi_yearly,
    macro_germany_zew,
)

"""
基金规模和规模趋势
"""
from mssdk.fund.fund_em_aum import fund_em_aum, fund_em_aum_trend, fund_em_aum_hist

"""
CRIX 数据
"""
from mssdk.crypto.crypto_crix import crypto_crix

"""
CME 比特币成交量
"""
from mssdk.crypto.crypto_bitcoin_cme import crypto_bitcoin_cme

"""
盘口异动
"""
from mssdk.stock_feature.stock_pankou import stock_changes_em

"""
A 股东方财富
"""
from mssdk.stock_feature.stock_em_hist import (
    stock_zh_a_spot_em,
    stock_zh_a_hist,
    stock_hk_spot_em,
    stock_hk_hist,
    stock_us_spot_em,
    stock_us_hist,
    stock_zh_a_hist_min_em,
    stock_zh_a_hist_pre_min_em,
    stock_hk_hist_min_em,
    stock_us_hist_min_em,
    stock_zh_b_spot_em,
)

"""
中行人民币牌价历史数据查询
"""
from mssdk.currency.currency_sina_china_bank import currency_boc_sina

"""
期货持仓
"""
from mssdk.futures_derivative.futures_sina_cot import futures_sina_hold_pos

"""
股东户数
"""
from mssdk.stock_feature.stock_gdhs import stock_zh_a_gdhs, stock_zh_a_gdhs_detail_em

"""
两网及退市
"""
from mssdk.stock.stock_stop import stock_staq_net_stop

"""
每日快讯数据
"""
from mssdk.stock_feature.stock_cls_alerts import stock_zh_a_alerts_cls

"""
涨停板行情
"""
from mssdk.stock_feature.stock_em_ztb import (
    stock_em_zt_pool,
    stock_em_zt_pool_previous,
    stock_em_zt_pool_dtgc,
    stock_em_zt_pool_zbgc,
    stock_em_zt_pool_strong,
    stock_em_zt_pool_sub_new,
)

"""
中国-香港-宏观
"""
from mssdk.economic.macro_china_hk import (
    marco_china_hk_cpi,
    marco_china_hk_cpi_ratio,
    marco_china_hk_trade_diff_ratio,
    marco_china_hk_gbp_ratio,
    marco_china_hk_building_amount,
    marco_china_hk_building_volume,
    marco_china_hk_gbp,
    marco_china_hk_ppi,
    marco_china_hk_rate_of_unemployment,
)

"""
增发和配股
"""
from mssdk.stock_feature.stock_zf_pg import stock_em_qbzf, stock_em_pg

"""
平均持仓
"""
from mssdk.stock_feature.stock_legu_average_position import (
    stock_average_position_legu,
)

"""
汽车销量
"""
from mssdk.other.other_car import car_gasgoo_sale_rank, car_cpca_energy_sale

"""
中国公路物流运价、运量指数
"""
from mssdk.index.index_cflp import index_cflp_price, index_cflp_volume

"""
赚钱效应分析
"""
from mssdk.stock_feature.stock_legu_market import stock_market_activity_legu

"""
浙江省排污权交易指数
"""
from mssdk.index.index_eri import index_eri

"""
Drewry 集装箱指数
"""
from mssdk.index.drewry_index import drewry_wci_index

"""
柯桥指数
"""
from mssdk.index.index_kq_fz import index_kq_fz
from mssdk.index.index_kq_ss import index_kq_fashion

"""
问财-热门股票
"""
from mssdk.stock_feature.stock_wencai import stock_wc_hot_rank

"""
新发基金
"""
from mssdk.fund.fund_em_init import fund_em_new_found

"""
高管持股
"""
from mssdk.stock_feature.stock_em_gdzjc import stock_em_ggcg

"""
同花顺-数据中心-资金流向-概念资金流
"""
from mssdk.stock_feature.stock_fund_flow import (
    stock_fund_flow_concept,
    stock_fund_flow_industry,
    stock_fund_flow_big_deal,
    stock_fund_flow_individual,
)

"""
比特币持仓
"""
from mssdk.crypto.crypto_hold import crypto_bitcoin_hold_report

"""
证券交易营业部排行
"""
from mssdk.stock_feature.stock_lh_yybpm import (
    stock_lh_yyb_capital,
    stock_lh_yyb_most,
    stock_lh_yyb_control,
)

"""
沪深 A 股公告
"""
from mssdk.stock_fundamental.stock_notice import stock_notice_report

"""
首发企业申报
"""
from mssdk.stock_fundamental.stock_ipo_declare import stock_ipo_declare

"""
三大报表
"""
from mssdk.stock_feature.stock_em_report import (
    stock_em_zcfz,
    stock_em_lrb,
    stock_em_xjll,
)

"""
业绩报告
"""
from mssdk.stock_feature.stock_em_yjbb import stock_em_yjbb

"""
同花顺-行业板块
"""
from mssdk.stock_feature.stock_board_industry_ths import (
    stock_board_industry_cons_ths,
    stock_board_industry_name_ths,
    stock_board_industry_info_ths,
    stock_board_industry_index_ths,
    stock_ipo_benefit_ths,
)

"""
同花顺-概念板块
"""
from mssdk.stock_feature.stock_board_concept_ths import (
    stock_board_concept_cons_ths,
    stock_board_concept_name_ths,
    stock_board_concept_info_ths,
    stock_board_concept_hist_ths,
    stock_board_cons_ths,
)

"""
分红配送
"""
from mssdk.stock_feature.stock_em_fhps import stock_em_fhps

"""
中美国债收益率
"""
from mssdk.bond.bond_em import bond_zh_us_rate

"""
盈利预测
"""
from mssdk.stock_fundamental.stock_profit_forecast import stock_profit_forecast

"""
基金经理
"""
from mssdk.fund.fund_manager import fund_manager

"""
基金评级
"""
from mssdk.fund.fund_rating import (
    fund_rating_sh,
    fund_rating_zs,
    fund_rating_ja,
    fund_rating_all,
)

"""
融资融券数据
"""
from mssdk.stock_feature.stock_sse_margin import (
    stock_margin_detail_sse,
    stock_margin_sse,
)

"""
期货交割和期转现
"""
from mssdk.futures.futures_to_spot import (
    futures_to_spot_czce,
    futures_to_spot_shfe,
    futures_to_spot_dce,
    futures_delivery_dce,
    futures_delivery_shfe,
    futures_delivery_czce,
    futures_delivery_match_dce,
    futures_delivery_match_czce,
)

"""
基金持仓
"""
from mssdk.fund.fund_em_portfolio import fund_portfolio_hold_em

"""
债券概览
"""
from mssdk.bond.bond_summary import bond_deal_summary_sse, bond_cash_summary_sse

"""
新闻-个股新闻
"""
from mssdk.news.news_stock import stock_news_em

"""
股票数据-一致行动人
"""
from mssdk.stock_feature.stock_em_yzxdr import stock_em_yzxdr

"""
大宗交易
"""
from mssdk.stock.stock_dzjy import (
    stock_dzjy_sctj,
    stock_dzjy_mrmx,
    stock_dzjy_mrtj,
    stock_dzjy_hygtj,
    stock_dzjy_yybph,
    stock_dzjy_hyyybtj,
)

"""
国证指数
"""
from mssdk.index.index_cni import (
    index_cni_hist,
    index_cni_all,
    index_cni_detail,
    index_cni_detail_hist,
    index_cni_detail_hist_adjust,
)

"""
金十数据-新闻资讯
"""
from mssdk.ws.js_ws_news import js_news

"""
东方财富-期权
"""
from mssdk.option.option_em import option_current_em

"""
科创板报告
"""
from mssdk.stock.stock_zh_kcb_report import stock_zh_kcb_report_em

"""
期货合约详情
"""
from mssdk.futures.futures_contract_detail import futures_contract_detail

"""
胡润排行榜
"""
from mssdk.fortune.fortune_hurun import hurun_rank

"""
新财富富豪榜
"""
from mssdk.fortune.fortune_xincaifu_500 import xincaifu_rank

"""
福布斯中国榜单
"""
from mssdk.fortune.fortune_forbes_500 import forbes_rank

"""
回购定盘利率
"""
from mssdk.rate.repo_rate import repo_rate_hist

"""
公募基金排行
"""
from mssdk.fund.fund_em_rank import (
    fund_em_exchange_rank,
    fund_em_money_rank,
    fund_em_open_fund_rank,
    fund_em_hk_rank,
    fund_em_lcx_rank,
)

"""
英为财情-加密货币
"""
from mssdk.crypto.crypto_hist_investing import crypto_hist, crypto_name_map

"""
电影票房
"""
from mssdk.movie.movie_yien import (
    movie_boxoffice_cinema_daily,
    movie_boxoffice_cinema_weekly,
    movie_boxoffice_weekly,
    movie_boxoffice_daily,
    movie_boxoffice_monthly,
    movie_boxoffice_realtime,
    movie_boxoffice_yearly,
    movie_boxoffice_yearly_first_week,
)

"""
新闻联播文字稿
"""
from mssdk.news.news_cctv import news_cctv

"""
债券收盘收益率曲线历史数据
"""
from mssdk.bond.bond_china_money import (
    bond_china_close_return,
    bond_china_close_return_map,
)

"""
COMEX黄金-白银库存
"""
from mssdk.futures.futures_comex import futures_comex_inventory

"""
国债期货可交割券相关指标
"""
from mssdk.bond.bond_futures import bond_futures_deliverable_coupons

"""
A 股-特别标的
"""
from mssdk.stock.stock_zh_a_special import (
    stock_zh_a_new,
    stock_zh_a_st_em,
    stock_zh_a_new_em,
    stock_zh_a_stop_em,
)

"""
东方财富-注册制审核
"""
from mssdk.stock_fundamental.stock_register import (
    stock_register_kcb,
    stock_register_cyb,
    stock_register_db,
)

"""
新浪财经-龙虎榜
"""
from mssdk.stock_feature.stock_sina_lhb import (
    stock_sina_lhb_detail_daily,
    stock_sina_lhb_ggtj,
    stock_sina_lhb_jgmx,
    stock_sina_lhb_jgzz,
    stock_sina_lhb_yytj,
)

"""
中证指数
"""
from mssdk.index.zh_stock_index_csindex import (
    stock_zh_index_hist_csindex,
    stock_zh_index_value_csindex,
)

"""
股票基金持仓数据
"""
from mssdk.stock.stock_fund_hold import (
    stock_report_fund_hold,
    stock_report_fund_hold_detail,
)

"""
期货分钟数据
"""
from mssdk.futures.futures_zh_sina import (
    futures_zh_minute_sina,
    futures_zh_daily_sina,
)

"""
股票财务报告预约披露
"""
from mssdk.stock_feature.stock_cninfo_yjyg import stock_report_disclosure

"""
基金行情
"""
from mssdk.fund.fund_etf import fund_etf_hist_sina, fund_etf_category_sina

"""
交易日历
"""
from mssdk.tool.trade_date_hist import tool_trade_date_hist_sina

"""
commodity option
"""
from mssdk.option.option_commodity_sina import (
    option_sina_commodity_contract_list,
    option_sina_commodity_dict,
    option_sina_commodity_hist,
)

"""
A 股PE和PB
"""
from mssdk.stock_feature.stock_a_pb import stock_a_pb
from mssdk.stock_feature.stock_a_pe import stock_a_pe
from mssdk.stock_feature.stock_a_indicator import (
    stock_a_lg_indicator,
    stock_hk_eniu_indicator,
)
from mssdk.stock_feature.stock_a_high_low import stock_a_high_low_statistics
from mssdk.stock_feature.stock_a_below_net_asset_statistics import (
    stock_a_below_net_asset_statistics,
)

"""
彭博亿万富豪指数
"""
from mssdk.fortune.fortune_bloomberg import index_bloomberg_billionaires

"""
stock-券商业绩月报
"""
from mssdk.stock_feature.stock_em_qsjy import stock_em_qsjy

"""
futures-warehouse-receipt
"""
from mssdk.futures.futures_warehouse_receipt import (
    futures_czce_warehouse_receipt,
    futures_dce_warehouse_receipt,
    futures_shfe_warehouse_receipt,
)

"""
stock-js
"""
from mssdk.stock.stock_js_us import stock_js_price

"""
stock-summary
"""
from mssdk.stock.stock_summary import (
    stock_sse_summary,
    stock_szse_summary,
    stock_sse_deal_daily,
)

"""
股票-机构推荐池
"""
from mssdk.stock_fundamental.stock_recommend import (
    stock_institute_recommend,
    stock_institute_recommend_detail,
)

"""
股票-机构持股
"""
from mssdk.stock_fundamental.stock_hold import (
    stock_institute_hold_detail,
    stock_institute_hold,
)

"""
stock-info
"""
from mssdk.stock.stock_info import (
    stock_info_sh_delist,
    stock_info_sz_delist,
    stock_info_a_code_name,
    stock_info_sh_name_code,
    stock_info_bj_name_code,
    stock_info_sz_name_code,
    stock_info_sz_change_name,
    stock_info_change_name,
)

"""
stock-sector
"""
from mssdk.stock.stock_industry import stock_sector_spot, stock_sector_detail

"""
stock-fundamental
"""
from mssdk.stock_fundamental.stock_finance import (
    stock_financial_abstract,
    stock_financial_report_sina,
    stock_financial_analysis_indicator,
    stock_add_stock,
    stock_ipo_info,
    stock_history_dividend_detail,
    stock_history_dividend,
    stock_circulate_stock_holder,
    stock_restricted_shares,
    stock_fund_stock_holder,
    stock_main_stock_holder,
)

"""
stock-HK-fundamental
"""
from mssdk.stock_fundamental.stock_finance_hk import (
    stock_financial_hk_analysis_indicator_em,
    stock_financial_hk_report_em,
)

"""
stock_fund
"""
from mssdk.stock.stock_fund import (
    stock_individual_fund_flow,
    stock_market_fund_flow,
    stock_sector_fund_flow_rank,
    stock_individual_fund_flow_rank,
)

"""
air-quality
"""
from mssdk.air.air_zhenqi import (
    air_quality_hist,
    air_quality_rank,
    air_quality_watch_point,
    air_city_list,
)

"""
hf
"""
from mssdk.hf.hf_sp500 import hf_sp_500

"""
stock_em_yjyg
"""
from mssdk.stock_feature.stock_em_yjyg import (
    stock_em_yjyg,
    stock_em_yysj,
    stock_em_yjkb,
)

"""
stock
"""
from mssdk.stock_feature.stock_em_dxsyl import stock_em_dxsyl, stock_em_xgsglb

"""
article
"""
from mssdk.article.fred_md import fred_md, fred_qd

"""
covid_19 CSSE
"""
from mssdk.event.covid import (
    covid_19_csse_daily,
    covid_19_csse_global_confirmed,
    covid_19_csse_global_death,
    covid_19_csse_global_recovered,
    covid_19_csse_us_death,
    covid_19_csse_us_confirmed,
)

"""
futures_cscidx
"""
from mssdk.futures.futures_cscidx import futures_index_cscidx

"""
futures_em_spot_stock
"""
from mssdk.futures.futures_em_spot_stock import futures_spot_stock

"""
energy_oil
"""
from mssdk.energy.energy_oil import energy_oil_detail, energy_oil_hist

"""
index-vix
"""
from mssdk.economic.macro_other import index_vix

"""
futures-foreign
"""
from mssdk.futures.futures_foreign import futures_foreign_detail, futures_foreign_hist

"""
stock-em-tfp
"""
from mssdk.stock_feature.stock_em_tfp import stock_tfp_em

"""
stock-em-hsgt
"""
from mssdk.stock_feature.stock_em_hsgt import (
    stock_em_hsgt_north_acc_flow_in,
    stock_em_hsgt_north_cash,
    stock_em_hsgt_north_net_flow_in,
    stock_em_hsgt_south_acc_flow_in,
    stock_em_hsgt_south_cash,
    stock_em_hsgt_south_net_flow_in,
    stock_em_hsgt_hold_stock,
    stock_em_hsgt_hist,
    stock_em_hsgt_institution_statistics,
    stock_em_hsgt_stock_statistics,
    stock_em_hsgt_board_rank,
)

"""
stock-em-comment
"""
from mssdk.stock_feature.stock_em_comment import stock_em_comment

"""
stock-em-analyst
"""
from mssdk.stock_feature.stock_em_analyst import (
    stock_em_analyst_detail,
    stock_em_analyst_rank,
)

"""
tool-github
"""
from mssdk.tool.tool_github import tool_github_star_list, tool_github_email_address

"""
sgx futures data
"""
from mssdk.futures.futures_sgx_daily import futures_sgx_daily

"""
currency interface
"""
from mssdk.currency.currency import (
    currency_convert,
    currency_currencies,
    currency_history,
    currency_latest,
    currency_time_series,
)

"""
知识图谱
"""
from mssdk.nlp.nlp_interface import nlp_ownthink, nlp_answer

"""
微博舆情报告
"""
from mssdk.stock.stock_weibo_nlp import stock_js_weibo_nlp_time, stock_js_weibo_report

"""
金融期权-新浪
"""
from mssdk.option.option_finance_sina import (
    option_sina_cffex_hs300_list,
    option_sina_cffex_hs300_spot,
    option_sina_cffex_hs300_daily,
    option_sina_sse_list,
    option_sina_sse_expire_day,
    option_sina_sse_codes,
    option_sina_sse_spot_price,
    option_sina_sse_underlying_spot_price,
    option_sina_sse_greeks,
    option_sina_sse_minute,
    option_sina_sse_daily,
    option_sina_finance_minute,
)

"""
中国-慈善
"""
from mssdk.charity.charity_china import (
    charity_china_organization,
    charity_china_plan,
    charity_china_platform,
    charity_china_progress,
    charity_china_report,
    charity_china_trust,
)

"""
中国-特许经营数据
"""
from mssdk.event.franchise import franchise_china

"""
债券-沪深债券
"""
from mssdk.bond.bond_zh_sina import bond_zh_hs_daily, bond_zh_hs_spot
from mssdk.bond.bond_zh_cov_sina import (
    bond_zh_hs_cov_daily,
    bond_zh_hs_cov_spot,
    bond_cov_comparison,
    bond_zh_cov,
    bond_zh_cov_info,
    bond_zh_hs_cov_min,
)
from mssdk.bond.bond_convert import bond_cov_jsl

"""
for pro api
"""
from mssdk.pro.data_pro import pro_api

"""
for pro api token set
"""
from mssdk.utils.token_process import set_token

"""
债券质押式回购成交明细数据
"""
from mssdk.bond.china_repo import bond_repo_zh_tick

"""
新型肺炎
"""
from mssdk.event.covid import (
    covid_19_trip,
    covid_19_trace,
)

"""
基金数据接口
"""
from mssdk.fund.fund_em import (
    fund_em_open_fund_daily,
    fund_em_open_fund_info,
    fund_em_etf_fund_daily,
    fund_em_etf_fund_info,
    fund_em_financial_fund_daily,
    fund_em_financial_fund_info,
    fund_em_fund_name,
    fund_em_graded_fund_daily,
    fund_em_graded_fund_info,
    fund_em_money_fund_daily,
    fund_em_money_fund_info,
    fund_em_value_estimation,
    fund_em_hk_fund_hist,
)

"""
百度迁徙地图接口
"""
from mssdk.event.covid import (
    migration_area_baidu,
    migration_scale_baidu,
)

"""
新增-事件接口新型冠状病毒接口
"""
from mssdk.event.covid import (
    covid_19_163,
    covid_19_dxy,
    covid_19_baidu,
    covid_19_hist_city,
    covid_19_hist_province,
)

"""
英为财情-外汇-货币对历史数据
"""
from mssdk.fx.currency_investing import (
    currency_hist,
    currency_name_code,
    currency_pair_map,
)

"""
商品期权-郑州商品交易所-期权-历史数据
"""
from mssdk.option.option_czce import option_czce_hist

"""
宏观-经济数据-银行间拆借利率
"""
from mssdk.interest_rate.interbank_rate_em import rate_interbank

"""
东方财富网-经济数据-银行间拆借利率
"""
from mssdk.interest_rate.interbank_rate_em import rate_interbank

"""
金十数据中心-外汇情绪
"""
from mssdk.economic.macro_other import macro_fx_sentiment

"""
金十数据中心-经济指标-欧元区
"""
from mssdk.economic.macro_euro import (
    macro_euro_gdp_yoy,
    macro_euro_cpi_mom,
    macro_euro_cpi_yoy,
    macro_euro_current_account_mom,
    macro_euro_employment_change_qoq,
    macro_euro_industrial_production_mom,
    macro_euro_manufacturing_pmi,
    macro_euro_ppi_mom,
    macro_euro_retail_sales_mom,
    macro_euro_sentix_investor_confidence,
    macro_euro_services_pmi,
    macro_euro_trade_balance,
    macro_euro_unemployment_rate_mom,
    macro_euro_zew_economic_sentiment,
    macro_euro_lme_holding,
    macro_euro_lme_stock,
)

"""
金十数据中心-经济指标-央行利率-主要央行利率
"""
from mssdk.economic.macro_bank import (
    macro_bank_australia_interest_rate,
    macro_bank_brazil_interest_rate,
    macro_bank_china_interest_rate,
    macro_bank_brazil_interest_rate,
    macro_bank_english_interest_rate,
    macro_bank_euro_interest_rate,
    macro_bank_india_interest_rate,
    macro_bank_japan_interest_rate,
    macro_bank_newzealand_interest_rate,
    macro_bank_russia_interest_rate,
    macro_bank_switzerland_interest_rate,
    macro_bank_usa_interest_rate,
)

"""
义乌小商品指数
"""
from mssdk.index.index_yw import index_yw

"""
股票指数-股票指数-成份股
"""
from mssdk.index.index_cons import (
    index_stock_info,
    index_stock_cons,
    index_stock_hist,
    index_stock_cons_sina,
    index_stock_cons_csindex,
    stock_a_code_to_symbol,
)

"""
东方财富-股票账户
"""
from mssdk.stock_feature.stock_em_account import stock_em_account

"""
期货规则
"""
from mssdk.futures.futures_rule import futures_rule

"""
东方财富-商誉专题
"""
from mssdk.stock_feature.stock_em_sy import (
    stock_em_sy_profile,
    stock_em_sy_yq_list,
    stock_em_sy_jz_list,
    stock_em_sy_list,
    stock_em_sy_hy_list,
)

"""
东方财富-股票质押
"""
from mssdk.stock_feature.stock_em_gpzy import (
    stock_em_gpzy_pledge_ratio,
    stock_em_gpzy_profile,
    stock_em_gpzy_distribute_statistics_bank,
    stock_em_gpzy_distribute_statistics_company,
    stock_em_gpzy_industry_data,
    stock_em_gpzy_pledge_ratio_detail,
)

"""
东方财富-机构调研
"""
from mssdk.stock_feature.stock_em_jgdy import stock_em_jgdy_tj, stock_em_jgdy_detail

"""
IT桔子
"""
from mssdk.fortune.fortune_it_juzi import (
    death_company,
    maxima_company,
    nicorn_company,
)

"""
新浪主力连续接口
"""
from mssdk.futures_derivative.sina_futures_index import (
    futures_main_sina,
    futures_display_main_sina,
)

"""
中国宏观杠杆率数据
"""
from mssdk.economic.marco_cnbs import macro_cnbs

"""
大宗商品-现货价格指数
"""
from mssdk.index.index_spot import spot_goods

"""
成本-世界各大城市生活成本
"""
from mssdk.cost.cost_living import cost_living

"""
能源-碳排放权
"""
from mssdk.energy.energy_carbon import (
    energy_carbon_domestic,
    energy_carbon_bj,
    energy_carbon_eu,
    energy_carbon_gz,
    energy_carbon_hb,
    energy_carbon_sz,
)

"""
中国证券投资基金业协会-信息公示
"""
from mssdk.fund.fund_amac import (
    amac_manager_info,
    amac_member_info,
    amac_member_sub_info,
    amac_aoin_info,
    amac_fund_account_info,
    amac_fund_info,
    amac_fund_sub_info,
    amac_futures_info,
    amac_manager_cancelled_info,
    amac_securities_info,
    amac_fund_abs,
    amac_manager_classify_info,
    amac_person_fund_org_list,
    amac_person_bond_org_list,
)

"""
世界五百强公司排名接口
"""
from mssdk.fortune.fortune_500 import fortune_rank, fortune_rank_eng

"""
申万行业一级
"""
from mssdk.index.index_sw import (
    sw_index_representation_spot,
    sw_index_spot,
    sw_index_second_spot,
    sw_index_cons,
    sw_index_daily,
    sw_index_daily_indicator,
)

"""
谷歌指数
"""
from mssdk.index.index_google import google_index

"""
百度指数
"""
from mssdk.index.index_baidu import (
    baidu_search_index,
    baidu_info_index,
    baidu_media_index,
)

"""
微博指数
"""
from mssdk.index.index_weibo import weibo_index

"""
经济政策不确定性指数
"""
from mssdk.article.epu_index import article_epu_index

"""
南华期货-南华指数
"""
from mssdk.futures_derivative.nh_index_return import futures_nh_return_index
from mssdk.futures_derivative.nh_index_price import (
    futures_nh_price_index,
    futures_nh_index_symbol_table,
)
from mssdk.futures_derivative.nh_index_volatility import futures_nh_volatility_index

"""
空气-河北
"""
from mssdk.air.air_hebei import air_quality_hebei

"""
timeanddate-日出和日落
"""
from mssdk.air.time_and_date import sunrise_daily, sunrise_monthly

"""
新浪-指数实时行情和历史行情
"""
from mssdk.stock.stock_zh_a_tick_tx_163 import (
    stock_zh_a_tick_tx,
    stock_zh_a_tick_tx_js,
    stock_zh_a_tick_163,
    stock_zh_a_tick_163_now,
)

"""
新浪-指数实时行情和历史行情
"""
from mssdk.index.zh_stock_index_sina import (
    stock_zh_index_daily,
    stock_zh_index_spot,
    stock_zh_index_daily_tx,
    stock_zh_index_daily_em,
)

"""
外盘期货实时行情
"""
from mssdk.futures.futures_hq_sina import (
    futures_foreign_commodity_realtime,
    futures_foreign_commodity_subscribe_exchange_symbol,
)

"""
FF多因子数据接口
"""
from mssdk.article.ff_factor import article_ff_crr

"""
Realized Library 接口
"""
from mssdk.article.risk_rv import (
    article_oman_rv,
    article_oman_rv_short,
    article_rlab_rv,
)

"""
银保监分局本级行政处罚数据
"""
from mssdk.bank.bank_cbirc_2020 import bank_fjcf_table_detail

"""
科创板股票
"""
from mssdk.stock.stock_zh_kcb_sina import stock_zh_kcb_spot, stock_zh_kcb_daily

"""
A股
"""
from mssdk.stock.stock_zh_a_sina import (
    stock_zh_a_spot,
    stock_zh_a_daily,
    stock_zh_a_minute,
    stock_zh_a_cdr_daily,
)

"""
A+H股
"""
from mssdk.stock.stock_zh_ah_tx import (
    stock_zh_ah_spot,
    stock_zh_ah_daily,
    stock_zh_ah_name,
)

"""
加密货币
"""
from mssdk.economic.macro_other import crypto_js_spot

"""
金融期权
"""
from mssdk.option.option_finance import (
    option_finance_board,
    option_finance_underlying,
)

"""
新浪-美股实时行情数据和历史行情数据(前复权)
"""
from mssdk.stock.stock_us_sina import (
    stock_us_daily,
    stock_us_spot,
    get_us_stock_name,
    stock_us_fundamental,
)

"""
新浪-港股实时行情数据和历史数据(前复权和后复权因子)
"""
from mssdk.stock.stock_hk_sina import stock_hk_daily, stock_hk_spot

"""
新浪-期货实时数据
"""
from mssdk.futures.futures_zh_sina import futures_zh_spot, match_main_contract

"""
西本新干线-指数数据
"""
from mssdk.futures_derivative.futures_xgx import _get_code_pic, futures_xgx_index

"""
生意社-商品与期货-现期图数据
"""
from mssdk.futures_derivative.sys_spot_futures import (
    get_sys_spot_futures,
    get_sys_spot_futures_dict,
)

"""
和讯财经-行情及历史数据
"""
from mssdk.stock.stock_us_zh_hx import stock_us_zh_spot, stock_us_zh_daily

"""
和讯财经-企业社会责任
"""
from mssdk.stock.stock_zh_zrbg_hx import stock_zh_a_scr_report

"""
全球宏观-机构宏观
"""
from mssdk.economic.macro_constitute import (
    macro_cons_gold_amount,
    macro_cons_gold_change,
    macro_cons_gold_volume,
    macro_cons_opec_month,
    macro_cons_silver_amount,
    macro_cons_silver_change,
    macro_cons_silver_volume,
)

"""
全球宏观-美国宏观
"""
from mssdk.economic.macro_usa import (
    macro_usa_eia_crude_rate,
    macro_usa_non_farm,
    macro_usa_unemployment_rate,
    macro_usa_adp_employment,
    macro_usa_core_pce_price,
    macro_usa_cpi_monthly,
    macro_usa_crude_inner,
    macro_usa_gdp_monthly,
    macro_usa_initial_jobless,
    macro_usa_lmci,
    macro_usa_api_crude_stock,
    macro_usa_building_permits,
    macro_usa_business_inventories,
    macro_usa_cb_consumer_confidence,
    macro_usa_core_cpi_monthly,
    macro_usa_core_ppi,
    macro_usa_current_account,
    macro_usa_durable_goods_orders,
    macro_usa_trade_balance,
    macro_usa_spcs20,
    macro_usa_services_pmi,
    macro_usa_rig_count,
    macro_usa_retail_sales,
    macro_usa_real_consumer_spending,
    macro_usa_ppi,
    macro_usa_pmi,
    macro_usa_personal_spending,
    macro_usa_pending_home_sales,
    macro_usa_nfib_small_business,
    macro_usa_new_home_sales,
    macro_usa_nahb_house_market_index,
    macro_usa_michigan_consumer_sentiment,
    macro_usa_exist_home_sales,
    macro_usa_export_price,
    macro_usa_factory_orders,
    macro_usa_house_price_index,
    macro_usa_house_starts,
    macro_usa_import_price,
    macro_usa_industrial_production,
    macro_usa_ism_non_pmi,
    macro_usa_ism_pmi,
    macro_usa_job_cuts,
    macro_usa_cftc_nc_holding,
    macro_usa_cftc_c_holding,
    macro_usa_cftc_merchant_currency_holding,
    macro_usa_cftc_merchant_goods_holding,
    macro_usa_phs,
)

"""
全球宏观-中国宏观
"""
from mssdk.economic.macro_china import (
    macro_china_cpi_monthly,
    macro_china_cpi_yearly,
    macro_china_m2_yearly,
    macro_china_fx_reserves_yearly,
    macro_china_cx_pmi_yearly,
    macro_china_pmi_yearly,
    macro_china_daily_energy,
    macro_china_non_man_pmi,
    macro_china_rmb,
    macro_china_gdp_yearly,
    macro_china_shrzgm,
    macro_china_ppi_yearly,
    macro_china_cx_services_pmi_yearly,
    macro_china_market_margin_sh,
    macro_china_market_margin_sz,
    macro_china_au_report,
    macro_china_ctci_detail,
    macro_china_ctci_detail_hist,
    macro_china_ctci,
    macro_china_exports_yoy,
    macro_china_hk_market_info,
    macro_china_imports_yoy,
    macro_china_trade_balance,
    macro_china_shibor_all,
    macro_china_industrial_production_yoy,
    macro_china_gyzjz,
    macro_china_lpr,
    macro_china_new_house_price,
    macro_china_enterprise_boom_index,
    macro_china_national_tax_receipts,
    macro_china_new_financial_credit,
    macro_china_fx_gold,
    macro_china_money_supply,
    macro_china_stock_market_cap,
    macro_china_cpi,
    macro_china_gdp,
    macro_china_ppi,
    macro_china_pmi,
    macro_china_gdzctz,
    macro_china_hgjck,
    macro_china_czsr,
    macro_china_whxd,
    macro_china_wbck,
    macro_china_bond_public,
    macro_china_gksccz,
    macro_china_hb,
    macro_china_xfzxx,
    macro_china_reserve_requirement_ratio,
    macro_china_consumer_goods_retail,
    macro_china_society_electricity,
    macro_china_society_traffic_volume,
    macro_china_postal_telecommunicational,
    macro_china_international_tourism_fx,
    macro_china_passenger_load_factor,
    macro_china_freight_index,
    macro_china_central_bank_balance,
    macro_china_insurance,
    macro_china_supply_of_money,
    macro_china_swap_rate,
    macro_china_foreign_exchange_gold,
    macro_china_retail_price_index,
    macro_china_real_estate,
    macro_china_qyspjg,
    macro_china_fdi,
)

"""
全球期货
"""
from mssdk.futures.futures_international import (
    futures_global_commodity_hist,
    futures_global_commodity_name_url_map,
)

"""
外汇
"""
from mssdk.fx.fx_quote import fx_pair_quote, fx_spot_quote, fx_swap_quote

"""
债券行情
"""
from mssdk.bond.china_bond import bond_spot_quote, bond_spot_deal, bond_china_yield

"""
商品期权
"""
from mssdk.option.option_commodity import (
    option_dce_daily,
    option_czce_daily,
    option_shfe_daily,
)

"""
英为财情-债券
"""
from mssdk.bond.bond_investing import (
    bond_investing_global,
    bond_investing_global_country_name_url,
)

"""
英为财情-指数
"""
from mssdk.index.index_investing import (
    index_investing_global,
    index_investing_global_country_name_url,
    index_investing_global_from_url,
)

"""
99期货-期货库存数据
"""
from mssdk.futures.futures_inventory import futures_inventory_99

"""
东方财富-期货库存数据
"""
from mssdk.futures.futures_inventory_em import futures_inventory_em

"""
中国银行间市场交易商协会
"""
from mssdk.bond.bond_bank import get_bond_bank

"""
奇货可查-工具模块
"""
from mssdk.qhkc_web.qhkc_tool import qhkc_tool_foreign, qhkc_tool_gdp

"""
奇货可查-指数模块
"""
from mssdk.qhkc_web.qhkc_index import (
    get_qhkc_index,
    get_qhkc_index_trend,
    get_qhkc_index_profit_loss,
)

"""
奇货可查-资金模块
"""
from mssdk.qhkc_web.qhkc_fund import (
    get_qhkc_fund_money_change,
    get_qhkc_fund_bs,
    get_qhkc_fund_position,
)

"""
大宗商品现货价格及基差
"""
from mssdk.futures.futures_basis import (
    futures_spot_price_daily,
    futures_spot_price,
    futures_spot_price_previous,
)

"""
期货持仓成交排名数据
"""
from mssdk.futures.cot import (
    get_rank_sum_daily,
    get_rank_sum,
    get_shfe_rank_table,
    get_czce_rank_table,
    get_dce_rank_table,
    get_cffex_rank_table,
    futures_dce_position_rank,
    futures_dce_position_rank_other,
)

"""
大宗商品仓单数据
"""
from mssdk.futures.receipt import get_receipt

"""
大宗商品展期收益率数据
"""
from mssdk.futures.futures_roll_yield import get_roll_yield_bar, get_roll_yield

"""
交易所日线行情数据
"""
from mssdk.futures.futures_daily_bar import (
    get_cffex_daily,
    get_czce_daily,
    get_shfe_v_wap,
    get_shfe_daily,
    get_dce_daily,
    get_futures_daily,
)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/6/22 15:08
Desc: 金十数据-比特币持仓报告
https://datacenter.jin10.com/dc_report?name=bitcoint
"""
import requests
import pandas as pd


def crypto_bitcoin_hold_report():
    """
    金十数据-比特币持仓报告
    https://datacenter.jin10.com/dc_report?name=bitcoint
    :return: 比特币持仓报告
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-api.jin10.com/bitcoin_treasuries/list"
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "referer": "https://datacenter.jin10.com/",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-version": "1.0.0",
    }
    params = {"_": "1618902583006"}
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["values"])
    temp_df.columns = [
        '代码',
        '公司名称-英文',
        '国家/地区',
        '市值',
        '比特币占市值比重',
        '持仓成本',
        '持仓占比',
        '持仓量',
        '当日持仓市值',
        '查询日期',
        '公告链接',
        '_',
        '分类',
        '倍数',
        '_',
        '公司名称-中文',
    ]
    temp_df = temp_df[[
        '代码',
        '公司名称-英文',
        '公司名称-中文',
        '国家/地区',
        '市值',
        '比特币占市值比重',
        '持仓成本',
        '持仓占比',
        '持仓量',
        '当日持仓市值',
        '查询日期',
        '公告链接',
        '分类',
        '倍数',
    ]]
    return temp_df


def crypto_bitcoin_hold_report():
    """
    金十数据-比特币持仓报告
    https://datacenter.jin10.com/dc_report?name=bitcoint
    :return: 比特币持仓报告
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-api.jin10.com/bitcoin_treasuries/list"
    headers = {
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "origin": "https://datacenter.jin10.com",
        "pragma": "no-cache",
        "referer": "https://datacenter.jin10.com/",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36",
        "x-app-id": "rU6QIu7JHe2gOUeR",
        "x-version": "1.0.0",
    }
    params = {"_": "1618902583006"}
    r = requests.get(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"]["values"])
    temp_df.columns = [
        '代码',
        '公司名称-英文',
        '国家/地区',
        '市值',
        '比特币占市值比重',
        '持仓成本',
        '持仓占比',
        '持仓量',
        '当日持仓市值',
        '查询日期',
        '公告链接',
        '_',
        '分类',
        '倍数',
        '_',
        '公司名称-中文',
    ]
    temp_df = temp_df[[
        '代码',
        '公司名称-英文',
        '公司名称-中文',
        '国家/地区',
        '市值',
        '比特币占市值比重',
        '持仓成本',
        '持仓占比',
        '持仓量',
        '当日持仓市值',
        '查询日期',
        '公告链接',
        '分类',
        '倍数',
    ]]
    return temp_df


if __name__ == '__main__':
    crypto_bitcoin_hold_report_df = crypto_bitcoin_hold_report()
    print(crypto_bitcoin_hold_report_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/7/5 22:49
Desc: 东方财富网-数据中心-特色数据-券商业绩月报
http://data.eastmoney.com/other/qsjy.html
"""
from mssdk.utils import demjson
import pandas as pd
import requests


def stock_em_qsjy(trade_date: str = "2020-01-01") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-券商业绩月报
    http://data.eastmoney.com/other/qsjy.html
    :param trade_date: 数据月份，从 2010-06-01 开始, e.g., 需要 2011 年 7 月, 则输入 2011-07-01
    :type trade_date: str
    :return: 券商业绩月报
    :rtype: pandas.DataFrame
    """
    url = "http://dcfm.eastmoney.com/em_mutisvcexpandinterface/api/js/get"
    params = {
        "type": "QSYJBG_MReport",
        "token": "70f12f2f4f091e459a279469fe49eca5",
        "st": "RQ",
        "sr": "-1",
        "p": "1",
        "ps": "1000",
        "js": "var KAHXVKzA={pages:(tp),data:(x)}",
        "filter": f"(RQ='{trade_date}T00:00:00')",
        "rt": "53132017",
    }
    r = requests.get(url, params=params)
    text_data = r.text
    data_json = demjson.decode(text_data[text_data.find("{"):])
    temp_df = pd.DataFrame(data_json["data"])
    temp_df["RQ"] = pd.to_datetime(temp_df["RQ"])
    temp_df["ENDATE"] = pd.to_datetime(temp_df["ENDATE"])
    temp_df.columns = ["开始日期",
                       "结束日期",
                       "简称",
                       "代码",
                       "当月净利润_净利润",
                       "当月净利润_同比增长",
                       "当月净利润_环比增长",
                       "当年累计净利润_累计净利润",
                       "_",
                       "当年累计净利润_同比增长",
                       "当月营业收入_营业收入",
                       "当月营业收入_环比增长",
                       "当月营业收入_同比增长",
                       "当年累计营业收入_累计营业收入",
                       "_",
                       "当年累计营业收入_同比增长",
                       "净资产_净资产",
                       "_",
                       "净资产_同比增长",
                       ]
    temp_df = temp_df[["开始日期",
                       "结束日期",
                       "简称",
                       "代码",
                       "当月净利润_净利润",
                       "当月净利润_同比增长",
                       "当月净利润_环比增长",
                       "当年累计净利润_累计净利润",
                       "当年累计净利润_同比增长",
                       "当月营业收入_营业收入",
                       "当月营业收入_环比增长",
                       "当月营业收入_同比增长",
                       "当年累计营业收入_累计营业收入",
                       "当年累计营业收入_同比增长",
                       "净资产_净资产",
                       "净资产_同比增长",
                       ]]
    return temp_df


if __name__ == '__main__':
    stock_em_qsjy_df = stock_em_qsjy(trade_date="2020-04-01")
    print(stock_em_qsjy_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/7/9 14:05
Desc: 东方财富-德国-经济数据
"""
from mssdk.utils import demjson
import pandas as pd
import requests


# 东方财富-德国-经济数据-IFO商业景气指数
def macro_germany_ifo() -> pd.DataFrame:
    """
    IFO商业景气指数
    http://data.eastmoney.com/cjsj/foreign_1_0.html
    :return: IFO商业景气指数
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "0",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-消费者物价指数月率终值
def macro_germany_cpi_monthly() -> pd.DataFrame:
    """
    消费者物价指数月率终值
    http://data.eastmoney.com/cjsj/foreign_1_1.html
    :return: 消费者物价指数月率终值
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "1",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-消费者物价指数年率终值
def macro_germany_cpi_yearly() -> pd.DataFrame:
    """
    消费者物价指数年率终值
    http://data.eastmoney.com/cjsj/foreign_1_2.html
    :return: 消费者物价指数年率终值
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "2",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-贸易帐(季调后)
def macro_germany_trade_adjusted() -> pd.DataFrame:
    """
    贸易帐(季调后)
    http://data.eastmoney.com/cjsj/foreign_1_3.html
    :return: 贸易帐(季调后)
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "3",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"]) * 10
    temp_df["现值"] = pd.to_numeric(temp_df["现值"]) * 10
    return temp_df


# 东方财富-德国-经济数据-GDP
def macro_germany_gdp() -> pd.DataFrame:
    """
    GDP
    http://data.eastmoney.com/cjsj/foreign_1_4.html
    :return: GDP
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "4",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-实际零售销售月率
def macro_germany_retail_sale_monthly() -> pd.DataFrame:
    """
    实际零售销售月率
    http://data.eastmoney.com/cjsj/foreign_1_5.html
    :return: 实际零售销售月率
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "5",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-实际零售销售年率
def macro_germany_retail_sale_yearly() -> pd.DataFrame:
    """
    实际零售销售年率
    http://data.eastmoney.com/cjsj/foreign_1_6.html
    :return: 实际零售销售年率
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "6",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


# 东方财富-德国-经济数据-ZEW 经济景气指数
def macro_germany_zew() -> pd.DataFrame:
    """
    ZEW 经济景气指数
    http://data.eastmoney.com/cjsj/foreign_1_7.html
    :return: ZEW 经济景气指数
    :rtype: pandas.DataFrame
    """
    url = "http://datainterface.eastmoney.com/EM_DataCenter/JS.aspx"
    params = {
        "type": "GJZB",
        "sty": "HKZB",
        "js": "({data:[(x)],pages:(pc)})",
        "p": "1",
        "ps": "2000",
        "mkt": "1",
        "stat": "7",
        "pageNo": "1",
        "pageNum": "1",
        "_": "1625474966006",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[1:-1])
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]])
    temp_df.columns = [
        "时间",
        "前值",
        "现值",
        "发布日期",
    ]
    temp_df["前值"] = pd.to_numeric(temp_df["前值"])
    temp_df["现值"] = pd.to_numeric(temp_df["现值"])
    return temp_df


if __name__ == "__main__":
    macro_germany_ifo_df = macro_germany_ifo()
    print(macro_germany_ifo_df)

    macro_germany_cpi_monthly_df = macro_germany_cpi_monthly()
    print(macro_germany_cpi_monthly_df)

    macro_germany_cpi_yearly_df = macro_germany_cpi_yearly()
    print(macro_germany_cpi_yearly_df)

    macro_germany_trade_adjusted_df = macro_germany_trade_adjusted()
    print(macro_germany_trade_adjusted_df)

    macro_germany_gdp_df = macro_germany_gdp()
    print(macro_germany_gdp_df)

    macro_germany_retail_sale_monthly_df = macro_germany_retail_sale_monthly()
    print(macro_germany_retail_sale_monthly_df)

    macro_germany_retail_sale_yearly_df = macro_germany_retail_sale_yearly()
    print(macro_germany_retail_sale_yearly_df)

    macro_germany_zew_df = macro_germany_zew()
    print(macro_germany_zew_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/7/23 14:24
Desc: 债券-集思录-可转债
集思录：https://app.jisilu.cn/data/cbnew/#cb
"""
import pandas as pd
import requests


def bond_cov_jsl(cookie: None = '') -> pd.DataFrame:
    """
    集思录可转债
    https://app.jisilu.cn/data/cbnew/#cb
    :return: 集思录可转债
    :rtype: pandas.DataFrame
    """
    url = "https://app.jisilu.cn/data/cbnew/cb_list/"
    headers = {
        'accept': 'application/json, text/javascript, */*; q=0.01',
        'accept-encoding': 'gzip, deflate, br',
        'accept-language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'cache-control': 'no-cache',
        'content-length': '220',
        'content-type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'cookie': cookie,
        'origin': 'https://app.jisilu.cn',
        'pragma': 'no-cache',
        'referer': 'https://app.jisilu.cn/data/cbnew/',
        'sec-ch-ua': '" Not;A Brand";v="99", "Google Chrome";v="91", "Chromium";v="91"',
        'sec-ch-ua-mobile': '?0',
        'sec-fetch-dest': 'empty',
        'sec-fetch-mode': 'cors',
        'sec-fetch-site': 'same-origin',
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36',
        'x-requested-with': 'XMLHttpRequest'
    }
    params = {
        "___jsl": "LST___t=1627021692978",
    }
    payload = {
        "fprice": "",
        "tprice": "",
        "curr_iss_amt": "",
        "volume": "",
        "svolume": "",
        "premium_rt": "",
        "ytm_rt": "",
        "market": "",
        "rating_cd": "",
        "is_search": "N",
        'market_cd[]': 'shmb',
        'market_cd[]': 'shkc',
        'market_cd[]': 'szmb',
        'market_cd[]': 'szcy',
        "btype": "",
        "listed": "Y",
        'qflag': 'N',
        "sw_cd": "",
        "bond_ids": "",
        "rp": "50",
    }
    r = requests.post(url, params=params, json=payload, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame([item["cell"] for item in data_json["rows"]])
    return temp_df


if __name__ == '__main__':
    bond_convert_jsl_df = bond_cov_jsl(cookie='')
    print(bond_convert_jsl_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2021/11/2 17:43
Desc: 
"""
# import time
#
# import requests
# import pandas as pd
# import time
# from bs4 import BeautifulSoup
#
# url = "http://stock.finance.sina.com.cn/stock/go.php/vPerformancePrediction/kind/eps/index.phtml"
# big_df = pd.DataFrame()
# page = 1
# while 1:
#     params = {
#         'num': '500',
#         'p': page,
#     }
#     print(page)
#     r = requests.get(url, params=params)
#     try:
#         temp_df = pd.read_html(r.text)[0]
#         big_df = big_df.append(temp_df, ignore_index=True)
#         page += 1
#         time.sleep(5)
#     except:
#         break
# big_df



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2019/10/17 1:19
Desc: 指数配置文件
"""
from calendar import monthrange
from datetime import date, timedelta
from functools import partial
from time import sleep

import pandas as pd

from mssdk.index.exceptions import ResponseError
from mssdk.index.request import TrendReq


def get_last_date_of_month(year: int, month: int) -> date:
    """Given a year and a month returns an instance of the date class
    containing the last day of the corresponding month.

    Source: https://stackoverflow.com/questions/42950/get-last-day-of-the-month-in-python
    """
    return date(year, month, monthrange(year, month)[1])


def convert_dates_to_timeframe(start: date, stop: date) -> str:
    """Given two dates, returns a stringified version of the interval between
    the two dates which is used to retrieve data for a specific time frame
    from Google Trends.
    """
    return f"{start.strftime('%Y-%m-%d')} {stop.strftime('%Y-%m-%d')}"


def _fetch_data(pytrends, build_payload, timeframe: str) -> pd.DataFrame:
    """Attempts to fecth data and retries in case of a ResponseError."""
    attempts, fetched = 0, False
    while not fetched:
        try:
            build_payload(timeframe=timeframe)
        except ResponseError as err:
            print(err)
            print(f'Trying again in {60 + 5 * attempts} seconds.')
            sleep(60 + 5 * attempts)
            attempts += 1
            if attempts > 3:
                print('Failed after 3 attemps, abort fetching.')
                break
        else:
            fetched = True
    return pytrends.interest_over_time()


def get_daily_data(word: str,
                   start_year: int,
                   start_mon: int,
                   stop_year: int,
                   stop_mon: int,
                   geo: str = 'US',
                   verbose: bool = True,
                   wait_time: float = 5.0) -> pd.DataFrame:
    """Given a word, fetches daily search volume data from Google Trends and
    returns results in a pandas DataFrame.

    Details: Due to the way Google Trends scales and returns data, special
    care needs to be taken to make the daily data comparable over different
    months. To do that, we download daily data on a month by month basis,
    and also monthly data. The monthly data is downloaded in one go, so that
    the monthly values are comparable amongst themselves and can be used to
    scale the daily data. The daily data is scaled by multiplying the daily
    value by the monthly search volume divided by 100.
    For a more detailed explanation see http://bit.ly/trendsscaling

    Args:
        word (str): Word to fetch daily data for.
        start_year (int): the start year
        start_mon (int): start 1st day of the month
        stop_year (int): the end year
        stop_mon (int): end at the last day of the month
        geo (str): geolocation
        verbose (bool): If True, then prints the word and current time frame
            we are fecthing the data for.

    Returns:
        complete (pd.DataFrame): Contains 4 columns.
            The column named after the word argument contains the daily search
            volume already scaled and comparable through time.
            The column f'{word}_unscaled' is the original daily data fetched
            month by month, and it is not comparable across different months
            (but is comparable within a month).
            The column f'{word}_monthly' contains the original monthly data
            fetched at once. The values in this column have been backfilled
            so that there are no NaN present.
            The column 'scale' contains the scale used to obtain the scaled
            daily data.
    """

    # Set up start and stop dates
    start_date = date(start_year, start_mon, 1)
    stop_date = get_last_date_of_month(stop_year, stop_mon)

    # Start pytrends for US region
    pytrends = TrendReq(hl='en-US', tz=360)
    # Initialize build_payload with the word we need data for
    build_payload = partial(pytrends.build_payload,
                            kw_list=[word], cat=0, geo=geo, gprop='')

    # Obtain monthly data for all months in years [start_year, stop_year]
    monthly = _fetch_data(pytrends, build_payload,
                          convert_dates_to_timeframe(start_date, stop_date))

    # Get daily data, month by month
    results = {}
    # if a timeout or too many requests error occur we need to adjust wait time
    current = start_date
    while current < stop_date:
        last_date_of_month = get_last_date_of_month(current.year, current.month)
        timeframe = convert_dates_to_timeframe(current, last_date_of_month)
        if verbose:
            print(f'{word}:{timeframe}')
        results[current] = _fetch_data(pytrends, build_payload, timeframe)
        current = last_date_of_month + timedelta(days=1)
        sleep(wait_time)  # don't go too fast or Google will send 429s

    daily = pd.concat(results.values()).drop(columns=['isPartial'])
    complete = daily.join(monthly, lsuffix='_unscaled', rsuffix='_monthly')

    # Scale daily data by monthly weights so the data is comparable
    complete[f'{word}_monthly'].ffill(inplace=True)  # fill NaN values
    complete['scale'] = complete[f'{word}_monthly'] / 100
    complete[word] = complete[f'{word}_unscaled'] * complete.scale

    return complete



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2020/3/17 20:40
Desc:
"""
__version__ = "0.3.0-dev"

from .api import (
    get_country,
    get_data,
    get_series,
    get_dataframe,
    get_indicator,
    get_incomelevel,
    get_lendingtype,
    get_source,
    get_topic,
    search_countries,
    search_indicators,
)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/7/20 16:05
Desc: 碳排放交易
北京市碳排放权电子交易平台-北京市碳排放权公开交易行情
https://www.bjets.com.cn/article/jyxx/

深圳碳排放交易所-国内碳情
http://www.cerx.cn/dailynewsCN/index.htm

深圳碳排放交易所-国际碳情
http://www.cerx.cn/dailynewsOuter/index.htm

湖北碳排放权交易中心-现货交易数据-配额-每日概况
http://www.cerx.cn/dailynewsOuter/index.htm

广州碳排放权交易中心-行情信息
http://www.cnemission.com/article/hqxx/
"""
import re

from mssdk.utils import demjson
import pandas as pd
import requests
from bs4 import BeautifulSoup
from tqdm import tqdm


def energy_carbon_domestic(symbol: str = "湖北") -> pd.DataFrame:
    """
    碳交易网-行情信息
    http://www.tanjiaoyi.com/
    :param symbol: choice of {'湖北', '上海', '北京', '重庆', '广东', '天津', '深圳', '福建'}
    :type symbol: str
    :return:
    :rtype: pandas.DataFrame
    """
    url = "http://k.tanjiaoyi.com:8080/KDataController/getHouseDatasInAverage.do"
    params = {
        'lcnK': '53f75bfcefff58e4046ccfa42171636c',
        'brand': 'TAN',
        '_': '1626773022063',
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_json = demjson.decode(data_text[data_text.find("(")+1:-1])
    data_json.keys()
    temp_df = pd.DataFrame(data_json[symbol])
    temp_df.columns = [
        "成交价",
        "_",
        "成交量",
        "地点",
        "成交额",
        "日期",
        "_",
    ]
    temp_df = temp_df[[
        "日期",
        "成交价",
        "成交量",
        "成交额",
        "地点",
    ]]
    temp_df['日期'] = pd.to_datetime(temp_df['日期']).dt.date
    temp_df['成交价'] = pd.to_numeric(temp_df['成交价'])
    temp_df['成交量'] = pd.to_numeric(temp_df['成交量'])
    temp_df['成交额'] = pd.to_numeric(temp_df['成交额'])
    return temp_df


def energy_carbon_bj() -> pd.DataFrame:
    """
    北京市碳排放权电子交易平台-北京市碳排放权公开交易行情
    https://www.bjets.com.cn/article/jyxx/
    :return: 北京市碳排放权公开交易行情
    :rtype: pandas.DataFrame
    """
    url = 'https://www.bjets.com.cn/article/jyxx/'
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    total_page = soup.find('table').find('script').string.split('=')[-1].strip().strip(';').strip('"')
    temp_df = pd.DataFrame()
    for i in tqdm(range(1, int(total_page)+1), desc="Please wait for a moment", leave=False):
        if i == 1:
            i = ""
        url = f"https://www.bjets.com.cn/article/jyxx/?{i}"
        r = requests.get(url)
        r.encoding = "utf-8"
        df = pd.read_html(r.text)[0]
        temp_df = temp_df.append(df, ignore_index=True)
    temp_df.columns = ["日期", "成交量", "成交均价", "成交额"]
    temp_df['成交单位'] = temp_df['成交额'].str.split("(", expand=True).iloc[:, 1].str.split("）", expand=True).iloc[:, 0].str.split(")", expand=True).iloc[:, 0]
    temp_df['成交额'] = temp_df['成交额'].str.split("(", expand=True).iloc[:, 0].str.split("（", expand=True).iloc[:, 0]
    temp_df['成交量'] = pd.to_numeric(temp_df['成交量'])
    temp_df['成交均价'] = pd.to_numeric(temp_df['成交均价'])
    temp_df['成交额'] = temp_df['成交额'].str.replace(",", "")
    temp_df['成交额'] = pd.to_numeric(temp_df['成交额'], errors='coerce')
    temp_df['日期'] = pd.to_datetime(temp_df['日期']).dt.date
    return temp_df


def energy_carbon_sz() -> pd.DataFrame:
    """
    深圳碳排放交易所-国内碳情
    http://www.cerx.cn/dailynewsCN/index.htm
    :return: 国内碳情每日行情数据
    :rtype: pandas.DataFrame
    """
    url = "http://www.cerx.cn/dailynewsCN/index.htm"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    page_num = int(soup.find(attrs={"class": "pagebar"}).find_all("option")[-1].text)
    big_df = pd.read_html(r.text, header=0)[0]
    for page in tqdm(range(2, page_num+1), desc="Please wait for a moment", leave=False):
        url = f"http://www.cerx.cn/dailynewsCN/index_{page}.htm"
        r = requests.get(url)
        temp_df = pd.read_html(r.text, header=0)[0]
        big_df = big_df.append(temp_df, ignore_index=True)
    big_df['交易日期'] = pd.to_datetime(big_df['交易日期']).dt.date
    big_df['开盘价'] = pd.to_numeric(big_df['开盘价'])
    big_df['最高价'] = pd.to_numeric(big_df['最高价'])
    big_df['最低价'] = pd.to_numeric(big_df['最低价'])
    big_df['成交均价'] = pd.to_numeric(big_df['成交均价'])
    big_df['收盘价'] = pd.to_numeric(big_df['收盘价'])
    big_df['成交量'] = pd.to_numeric(big_df['成交量'])
    big_df['成交额'] = pd.to_numeric(big_df['成交额'])
    return big_df


def energy_carbon_eu() -> pd.DataFrame:
    """
    深圳碳排放交易所-国际碳情
    http://www.cerx.cn/dailynewsOuter/index.htm
    :return: 国际碳情每日行情数据
    :rtype: pandas.DataFrame
    """
    url = "http://www.cerx.cn/dailynewsOuter/index.htm"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    page_num = int(soup.find(attrs={"class": "pagebar"}).find_all("option")[-1].text)
    big_df = pd.read_html(r.text, header=0)[0]
    for page in tqdm(range(2, page_num+1), desc="Please wait for a moment", leave=False):
        url = f"http://www.cerx.cn/dailynewsOuter/index_{page}.htm"
        r = requests.get(url)
        temp_df = pd.read_html(r.text, header=0)[0]
        big_df = big_df.append(temp_df, ignore_index=True)
    big_df['交易日期'] = pd.to_datetime(big_df['交易日期']).dt.date
    big_df['开盘价'] = pd.to_numeric(big_df['开盘价'])
    big_df['最高价'] = pd.to_numeric(big_df['最高价'])
    big_df['最低价'] = pd.to_numeric(big_df['最低价'])
    big_df['成交均价'] = pd.to_numeric(big_df['成交均价'])
    big_df['收盘价'] = pd.to_numeric(big_df['收盘价'])
    big_df['成交量'] = pd.to_numeric(big_df['成交量'])
    big_df['成交额'] = pd.to_numeric(big_df['成交额'])
    return big_df


def energy_carbon_hb() -> pd.DataFrame:
    """
    湖北碳排放权交易中心-现货交易数据-配额-每日概况
    http://www.hbets.cn/list/13.html?page=42
    :return: 现货交易数据-配额-每日概况行情数据
    :rtype: pandas.DataFrame
    """
    url = "http://www.hbets.cn/list/13.html"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    page_string = soup.find('div', attrs={'class': 'page'}).find_all('span')[-1].text
    page_num = int(re.findall(r'\d+', page_string)[-1])
    columns = [item.text for item in soup.find('ul', attrs={"class": "title"}).find_all('li')]
    big_df = pd.DataFrame()
    for page in tqdm(range(1, page_num+1), desc="Please wait for a moment", leave=False):
        url = f"http://www.hbets.cn/list/13.html"
        params = {
            'page': page
        }
        r = requests.get(url, params=params)
        soup = BeautifulSoup(r.text, "lxml")
        page_node = [item for item in soup.find(attrs={"class": "future_table"}).find_all(attrs={"class": "cont"})]
        temp_list = []
        for item in page_node:
            temp_inner_list = []
            for inner_item in item.find_all("li"):
                temp_inner_list.append(inner_item.text)
            temp_list.append(temp_inner_list)
        temp_df = pd.DataFrame(temp_list)
        big_df = big_df.append(temp_df, ignore_index=True)
    big_df.columns = columns
    big_df['日期'] = pd.to_datetime(big_df['日期']).dt.date
    big_df['最新'] = pd.to_numeric(big_df['最新'])
    big_df['最高'] = big_df['最高'].str.replace("--", "")
    big_df['最高'] = pd.to_numeric(big_df['最高'])
    big_df['最低'] = big_df['最低'].str.replace("--", "")
    big_df['最低'] = pd.to_numeric(big_df['最低'])
    big_df['成交量'] = big_df['成交量'].str.replace("--", "")
    big_df['成交量'] = pd.to_numeric(big_df['成交量'])
    big_df['成交额'] = big_df['成交额'].str.replace("--", "")
    big_df['成交额'] = pd.to_numeric(big_df['成交额'])
    big_df['昨收盘价'] = big_df['昨收盘价'].str.replace("--", "")
    big_df['昨收盘价'] = pd.to_numeric(big_df['昨收盘价'])
    return big_df


def energy_carbon_gz() -> pd.DataFrame:
    """
    广州碳排放权交易中心-行情信息
    http://www.cnemission.com/article/hqxx/
    :return: 行情信息数据
    :rtype: pandas.DataFrame
    """
    url = "http://ets.cnemission.com/carbon/portalIndex/markethistory"
    params = {
        "Top": "1",
        "beginTime": "2010-01-01",
        "endTime": "2025-09-12",
    }
    r = requests.get(url, params=params)
    temp_df = pd.read_html(r.text, header=0)[1]
    return temp_df


if __name__ == '__main__':
    energy_carbon_domestic_df = energy_carbon_domestic(symbol="湖北")
    print(energy_carbon_domestic_df)

    energy_carbon_domestic_df = energy_carbon_domestic(symbol="深圳")
    print(energy_carbon_domestic_df)

    energy_carbon_bj_df = energy_carbon_bj()
    print(energy_carbon_bj_df)

    energy_carbon_sz_df = energy_carbon_sz()
    print(energy_carbon_sz_df)

    energy_carbon_eu_df = energy_carbon_eu()
    print(energy_carbon_eu_df)

    energy_carbon_hb_df = energy_carbon_hb()
    print(energy_carbon_hb_df)

    energy_carbon_gz_df = energy_carbon_gz()
    print(energy_carbon_gz_df)





#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/5/1 19:51
Desc: 义乌小商品指数
http://www.ywindex.com/Home/Product/index/
"""
import pandas as pd
import requests
from bs4 import BeautifulSoup


def index_yw(symbol: str = "月景气指数") -> pd.DataFrame:
    """
    义乌小商品指数
    http://www.ywindex.com/Home/Product/index/
    :param symbol: choice of {"周价格指数", "月价格指数", "月景气指数"}
    :type symbol: str
    :return: 指数结果
    :rtype: pandas.DataFrame
    """
    name_num_dict = {
        "周价格指数": 1,
        "月价格指数": 3,
        "月景气指数": 5,
    }
    url = "http://www.ywindex.com/Home/Product/index/"
    res = requests.get(url)
    soup = BeautifulSoup(res.text, "lxml")
    table_name = (
        soup.find_all(attrs={"class": "tablex"})[name_num_dict[symbol]]
        .get_text()
        .split("\n\n\n\n\n")[2]
        .split("\n")
    )
    table_content = (
        soup.find_all(attrs={"class": "tablex"})[name_num_dict[symbol]]
        .get_text()
        .split("\n\n\n\n\n")[3]
        .split("\n\n")
    )
    if symbol == "月景气指数":
        table_df = pd.DataFrame([item.split("\n") for item in table_content]).iloc[
            :, :5
        ]
        table_df.columns = table_name
        return table_df
    table_df = pd.DataFrame([item.split("\n") for item in table_content]).iloc[:, :6]
    table_df.columns = table_name
    return table_df


if __name__ == "__main__":
    index_yw_df = index_yw(symbol="周价格指数")
    print(index_yw_df)

    index_yw_df = index_yw(symbol="月价格指数")
    print(index_yw_df)

    index_yw_df = index_yw(symbol="月景气指数")
    print(index_yw_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/11/18 14:50
Desc: 首页-行情中心-涨停板行情-涨停股池
http://quote.eastmoney.com/ztb/detail#type=ztgc

涨停板行情专题为您展示了6个股票池，分别为
涨停股池：包含当日当前涨停的所有A股股票(不含未中断连续一字涨停板的新股)；
昨日涨停股池：包含上一交易日收盘时涨停的所有A股股票(不含未中断连续一字涨停板的新股)；
强势股池：包含创下60日新高或近期多次涨停的A股股票；
次新股池：包含上市一年以内且中断了连续一字涨停板的A股股票；
炸板股池：包含当日触及过涨停板且当前未封板的A股股票；
跌停股池：包含当日当前跌停的所有A股股票。
注：涨停板行情专题统计不包含ST股票及科创板股票。
"""
import pandas as pd
import requests


def stock_em_zt_pool(date: str = '20211118') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-涨停股池
    http://quote.eastmoney.com/ztb/detail#type=ztgc
    :return: 涨停股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getTopicZTPool'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '320',
        'sort': 'fbt:asc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '连板数',
        '首次封板时间',
        '最后封板时间',
        '封板资金',
        '炸板次数',
        '所属行业',
        '涨停统计',
    ]
    temp_df['涨停统计'] = temp_df['涨停统计'].apply(lambda x: dict(x)['days']).astype(str) + "/" + temp_df['涨停统计'].apply(lambda x: dict(x)['ct']).astype(str)
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '封板资金',
        '首次封板时间',
        '最后封板时间',
        '炸板次数',
        '涨停统计',
        '连板数',
        '所属行业',
    ]]
    temp_df['首次封板时间'] = temp_df['首次封板时间'].astype(str).str.zfill(6)
    temp_df['最后封板时间'] = temp_df['最后封板时间'].astype(str).str.zfill(6)
    temp_df['最新价'] = temp_df['最新价'] / 1000
    return temp_df


def stock_em_zt_pool_previous(date: str = '20210521') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-昨日涨停股池
    http://quote.eastmoney.com/ztb/detail#type=zrzt
    :return: 昨日涨停股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getYesterdayZTPool'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '170',
        'sort': 'zs:desc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨停价',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '振幅',
        '涨速',
        '昨日封板时间',
        '昨日连板数',
        '所属行业',
        '涨停统计',
    ]
    temp_df['涨停统计'] = temp_df['涨停统计'].apply(lambda x: dict(x)['days']).astype(str) + "/" + temp_df['涨停统计'].apply(lambda x: dict(x)['ct']).astype(str)
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '涨停价',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '涨速',
        '振幅',
        '昨日封板时间',
        '昨日连板数',
        '涨停统计',
        '所属行业',
    ]]
    temp_df['最新价'] = temp_df['最新价'] / 1000
    temp_df['涨停价'] = temp_df['涨停价'] / 1000
    temp_df['昨日封板时间'] = temp_df['昨日封板时间'].astype(str).str.zfill(6)
    return temp_df


def stock_em_zt_pool_strong(date: str = '20210521') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-强势股池
    http://quote.eastmoney.com/ztb/detail#type=qsgc
    :return: 强势股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getTopicQSPool'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '170',
        'sort': 'zdp:desc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨停价',
        '_',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '是否新高',
        '入选理由',
        '量比',
        '涨速',
        '涨停统计',
        '所属行业',
    ]
    temp_df['涨停统计'] = temp_df['涨停统计'].apply(lambda x: dict(x)['days']).astype(str) + "/" + temp_df['涨停统计'].apply(lambda x: dict(x)['ct']).astype(str)
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '涨停价',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '涨速',
        '是否新高',
        '量比',
        '涨停统计',
        '入选理由',
        '所属行业',
    ]]
    temp_df['最新价'] = temp_df['最新价'] / 1000
    temp_df['涨停价'] = temp_df['涨停价'] / 1000
    return temp_df


def stock_em_zt_pool_sub_new(date: str = '20210525') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-次新股池
    http://quote.eastmoney.com/ztb/detail#type=cxgc
    :return: 次新股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getTopicCXPooll'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '170',
        'sort': 'ods:asc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨停价',
        '_',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '转手率',
        '开板几日',
        '开板日期',
        '上市日期',
        '_',
        '是否新高',
        '涨停统计',
        '所属行业',
    ]
    temp_df['涨停统计'] = temp_df['涨停统计'].apply(lambda x: dict(x)['days']).astype(str) + "/" + temp_df['涨停统计'].apply(lambda x: dict(x)['ct']).astype(str)
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '涨停价',
        '成交额',
        '流通市值',
        '总市值',
        '转手率',
        '开板几日',
        '开板日期',
        '上市日期',
        '是否新高',
        '涨停统计',
        '所属行业',
    ]]
    temp_df['最新价'] = temp_df['最新价'] / 1000
    temp_df['涨停价'] = temp_df['涨停价'] / 1000
    temp_df.loc[temp_df['涨停价'] > 100000, '涨停价'] = '-'
    temp_df.loc[temp_df['上市日期'] == 0, '上市日期'] = '-'
    return temp_df


def stock_em_zt_pool_zbgc(date: str = '20210525') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-炸板股池
    http://quote.eastmoney.com/ztb/detail#type=zbgc
    :return: 炸板股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getTopicZBPool'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '170',
        'sort': 'fbt:asc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨停价',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '首次封板时间',
        '炸板次数',
        '振幅',
        '涨速',
        '涨停统计',
        '所属行业',
    ]
    temp_df['涨停统计'] = temp_df['涨停统计'].apply(lambda x: dict(x)['days']).astype(str) + "/" + temp_df['涨停统计'].apply(lambda x: dict(x)['ct']).astype(str)
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '涨停价',
        '成交额',
        '流通市值',
        '总市值',
        '换手率',
        '涨速',
        '首次封板时间',
        '炸板次数',
        '涨停统计',
        '振幅',
        '所属行业',
    ]]
    temp_df['最新价'] = temp_df['最新价'] / 1000
    temp_df['涨停价'] = temp_df['涨停价'] / 1000
    temp_df['首次封板时间'] = temp_df['首次封板时间'].astype(str).str.zfill(6)
    return temp_df


def stock_em_zt_pool_dtgc(date: str = '20210903') -> pd.DataFrame:
    """
    东方财富网-行情中心-涨停板行情-跌停股池
    http://quote.eastmoney.com/ztb/detail#type=dtgc
    :return: 跌停股池
    :rtype: pandas.DataFrame
    """
    url = 'http://push2ex.eastmoney.com/getTopicDTPool'
    params = {
        'ut': '7eea3edcaed734bea9cbfc24409ed989',
        'dpt': 'wz.ztzt',
        'Pageindex': '0',
        'pagesize': '170',
        'sort': 'fund:asc',
        'date': date,
        '_': '1621590489736',
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    if data_json['data'] is None:
        return None
    temp_df = pd.DataFrame(data_json['data']['pool'])
    temp_df.reset_index(inplace=True)
    temp_df['index'] = range(1, len(temp_df)+1)
    temp_df.columns = [
        '序号',
        '代码',
        '_',
        '名称',
        '最新价',
        '涨跌幅',
        '成交额',
        '流通市值',
        '总市值',
        '动态市盈率',
        '换手率',
        '封单资金',
        '最后封板时间',
        '板上成交额',
        '连续跌停',
        '开板次数',
        '所属行业',
    ]
    temp_df = temp_df[[
        '序号',
        '代码',
        '名称',
        '涨跌幅',
        '最新价',
        '成交额',
        '流通市值',
        '总市值',
        '动态市盈率',
        '换手率',
        '封单资金',
        '最后封板时间',
        '板上成交额',
        '连续跌停',
        '开板次数',
        '所属行业',
    ]]
    temp_df['最新价'] = temp_df['最新价'] / 1000
    temp_df['最后封板时间'] = temp_df['最后封板时间'].astype(str).str.zfill(6)
    return temp_df


if __name__ == '__main__':
    stock_em_zt_pool_df = stock_em_zt_pool(date='20211118')
    print(stock_em_zt_pool_df)

    stock_em_zt_pool_previous_df = stock_em_zt_pool_previous(date='20210525')
    print(stock_em_zt_pool_previous_df)

    stock_em_zt_pool_strong_df = stock_em_zt_pool_strong(date='20210525')
    print(stock_em_zt_pool_strong_df)

    stock_em_zt_pool_sub_new_df = stock_em_zt_pool_sub_new(date='20210525')
    print(stock_em_zt_pool_sub_new_df)

    stock_em_zt_pool_zbgc_df = stock_em_zt_pool_zbgc(date='20210527')
    print(stock_em_zt_pool_zbgc_df)

    stock_em_zt_pool_dtgc_df = stock_em_zt_pool_dtgc(date='20210903')
    print(stock_em_zt_pool_dtgc_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/7/20 20:10
Desc: 外盘期货-历史行情数据-日频率
http://finance.sina.com.cn/money/future/hf.html
"""
from datetime import datetime

import pandas as pd
import requests

from mssdk.futures.futures_hq_sina import futures_foreign_commodity_subscribe_exchange_symbol


def futures_foreign_hist(symbol: str = "ZSD") -> pd.DataFrame:
    """
    外盘期货-历史行情数据-日频率
    http://finance.sina.com.cn/money/future/hf.html
    :param symbol: futures symbol, you can get it from futures_foreign_commodity_subscribe_exchange_symbol
    :type symbol: str
    :return: historical data from 2010
    :rtype: pandas.DataFrame
    """
    today = f'{datetime.today().year}_{datetime.today().month}_{datetime.today().day}'
    url = f"https://stock2.finance.sina.com.cn/futures/api/jsonp.php/var%20_S{today}=/GlobalFuturesService.getGlobalFuturesDailyKLine"
    params = {
        "symbol": symbol,
        "_": today,
        "source": "web",
    }
    r = requests.get(url, params=params)
    data_text = r.text
    data_df = pd.read_json(data_text[data_text.find("["):-2])
    return data_df


def futures_foreign_detail(symbol: str = "ZSD") -> pd.DataFrame:
    """
    foreign futures contract detail data
    :param symbol: futures symbol, you can get it from hf_subscribe_exchange_symbol function
    :type symbol: str
    :return: contract detail
    :rtype: pandas.DataFrame
    """
    url = f"https://finance.sina.com.cn/futures/quotes/{symbol}.shtml"
    r = requests.get(url)
    r.encoding = "gbk"
    data_text = r.text
    data_df = pd.read_html(data_text)[6]
    return data_df


if __name__ == '__main__':
    futures_foreign_hist_df = futures_foreign_hist(symbol="ZSD")
    print(futures_foreign_hist_df)

    subscribes = futures_foreign_commodity_subscribe_exchange_symbol()

    for item in subscribes:
        futures_foreign_detail_df = futures_foreign_detail(symbol=item)
        print(futures_foreign_detail_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2021/11/16 21:12
Desc: 中国电竞价值排行榜
http://rank.uuu9.com/player/ranking
"""
import requests
import pandas as pd
from bs4 import BeautifulSoup


def club_rank_game(symbol: str = "英雄联盟") -> pd.DataFrame:
    """
    中国电竞价值排行榜-俱乐部排名
    http://rank.uuu9.com/
    :param symbol: choice of {'英雄联盟', '绝地求生', '王者荣耀', 'DOTA2', '穿越火线', '和平精英'}
    :type symbol: str
    :return: 俱乐部排名
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "DOTA2": "1",
        "英雄联盟": "2",
        "绝地求生": "3",
        "王者荣耀": "4",
        "穿越火线": "5",
        "和平精英": "6",
    }
    url = "http://rank.uuu9.com/club/ranking"
    params = {"gameId": symbol_map[symbol], "type": "0"}
    r = requests.get(url, params=params)
    soup = BeautifulSoup(r.text, "lxml")
    data_text = soup.find("div", attrs={"class": "ec_data"}).text
    report_date = data_text.split("：")[-1]
    temp_df = pd.read_html(r.text)[0]
    if symbol in {"英雄联盟", "王者荣耀", "DOTA2"}:
        temp_df.columns = [
            "排名",
            "俱乐部名称",
            "人气指数",
            "舆论指数",
            "战绩指数",
            "综合指数",
            "排名变动",
            "-",
        ]
        temp_df = temp_df[
            [
                "排名",
                "俱乐部名称",
                "人气指数",
                "舆论指数",
                "战绩指数",
                "综合指数",
                "排名变动",
            ]
        ]
    else:
        temp_df.columns = [
            "排名",
            "俱乐部名称",
            "人气指数",
            "舆论指数",
            "综合指数",
            "排名变动",
            "-",
        ]
        temp_df = temp_df[
            [
                "排名",
                "俱乐部名称",
                "人气指数",
                "舆论指数",
                "综合指数",
                "排名变动",
            ]
        ]
    temp_df['更新时间'] = report_date
    return temp_df


def player_rank_game(symbol: str = "英雄联盟") -> pd.DataFrame:
    """
    中国电竞价值排行榜-选手排行榜
    http://rank.uuu9.com/player/ranking
    :param symbol: choice of {'英雄联盟', '绝地求生', '王者荣耀', 'DOTA2', '穿越火线', '和平精英'}
    :type symbol: str
    :return: 选手排行榜
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "DOTA2": "1",
        "英雄联盟": "2",
        "绝地求生": "3",
        "王者荣耀": "4",
        "穿越火线": "5",
        "和平精英": "6",
    }
    url = "http://rank.uuu9.com/player/ranking"
    params = {"gameId": symbol_map[symbol], "type": "0"}
    r = requests.get(url, params=params)
    soup = BeautifulSoup(r.text, "lxml")
    data_text = soup.find("div", attrs={"class": "ec_data"}).text
    report_date = data_text.split("：")[-1]
    temp_df = pd.read_html(r.text)[0]
    if symbol == "王者荣耀":
        temp_df.columns = [
            "排名",
            "选手ID",
            "所属战队",
            "人气指数",
            "舆论指数",
            "战绩指数",
            "综合指数",
            "排名变动",
            "-",
        ]
        temp_df = temp_df[
            [
                "排名",
                "选手ID",
                "所属战队",
                "人气指数",
                "舆论指数",
                "战绩指数",
                "综合指数",
                "排名变动",
            ]
        ]
        temp_df['更新时间'] = report_date
        return temp_df
    if symbol in {"英雄联盟", "DOTA2"}:
        temp_df.columns = [
            "排名",
            "选手ID",
            "所属战队",
            "人气指数",
            "舆论指数",
            "战绩指数",
            "综合指数",
            "身价",
            "排名变动",
            "-",
        ]
        temp_df = temp_df[
            [
                "排名",
                "选手ID",
                "所属战队",
                "人气指数",
                "舆论指数",
                "战绩指数",
                "综合指数",
                "身价",
                "排名变动",
            ]
        ]
    else:
        temp_df.columns = [
            "排名",
            "选手ID",
            "所属战队",
            "人气指数",
            "舆论指数",
            "综合指数",
            "身价",
            "排名变动",
            "-",
        ]
        temp_df = temp_df[
            [
                "排名",
                "选手ID",
                "所属战队",
                "人气指数",
                "舆论指数",
                "综合指数",
                "身价",
                "排名变动",
            ]
        ]
    temp_df['更新时间'] = report_date
    return temp_df


if __name__ == "__main__":
    club_rank_game_df = club_rank_game(symbol="英雄联盟")
    print(club_rank_game_df)

    player_rank_game_df = player_rank_game(symbol="英雄联盟")
    print(player_rank_game_df)

    for item in ["英雄联盟", "绝地求生", "王者荣耀", "DOTA2", "穿越火线", "和平精英"]:
        print(item)

        club_rank_game_df = club_rank_game(symbol=item)
        print(club_rank_game_df)

        player_rank_game_df = player_rank_game(symbol=item)
        print(player_rank_game_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/10/31 17:03
Desc: 英为财情-股票指数-全球股指与期货指数数据接口
https://cn.investing.com/indices/volatility-s-p-500-historical-data
"""
import re

import pandas as pd
import requests
from bs4 import BeautifulSoup

from mssdk.index.cons import short_headers, long_headers


def _get_global_index_country_name_url() -> dict:
    """
    全球指数-各国的全球指数数据
    https://cn.investing.com/indices/global-indices?majorIndices=on&primarySectors=on&bonds=on&additionalIndices=on&otherIndices=on&c_id=37
    :return: 国家和代码
    :rtype: dict
    """
    url = "https://cn.investing.com/indices/global-indices"
    params = {
        "majorIndices": "on",
        "primarySectors": "on",
        "bonds": "on",
        "additionalIndices": "on",
        "otherIndices": "on",
    }
    r = requests.get(url, params=params, headers=short_headers)
    data_text = r.text
    soup = BeautifulSoup(data_text, "lxml")
    name_url_option_list = soup.find_all("option")[1:]
    url_list = [
        item["value"] for item in name_url_option_list if "c_id" in item["value"]
    ]
    url_list_code = [
        item["value"].split("?")[1].split("=")[1]
        for item in name_url_option_list
        if "c_id" in item["value"]
    ]
    name_list = [item.get_text() for item in name_url_option_list][: len(url_list)]
    _temp_df = pd.DataFrame([name_list, url_list_code]).T
    name_code_list = dict(zip(_temp_df.iloc[:, 0], _temp_df.iloc[:, 1]))
    return name_code_list


def _get_global_country_name_url() -> dict:
    """
    获取可获得指数数据国家对应的 URL
    :return: dict
    {'中国': '/indices/china-indices',
    '丹麦': '/indices/denmark-indices',
    '乌克兰': '/indices/ukraine-indices',
    '乌干达': '/indices/uganda-indices',
    '以色列': '/indices/israeli-indices',
    '伊拉克': '/indices/iraq-indices',
    '俄罗斯': '/indices/russia-indices',
    '保加利亚': '/indices/bulgaria-indices',
    '克罗地亚': '/indices/croatia-indices',
    '冰岛': '/indices/iceland-indices',
    '加拿大': '/indices/canada-indices',
    '匈牙利': '/indices/hungary-indices',
    '南非': '/indices/south-africa-indices',
    '博茨瓦纳': '/indices/botswana-indices',
    '卡塔尔': '/indices/qatar-indices',
    '卢旺达': '/indices/rwanda-indices',
    '卢森堡': '/indices/luxembourg-indices',
    '印度': '/indices/india-indices',
    '印度尼西亚': '/indices/indonesia-indices',
    '厄瓜多尔': '/indices/ecuador-indices',
    '台湾': '/indices/taiwan-indices',
    '哈萨克斯坦': '/indices/kazakhstan-indices',
    '哥伦比亚': '/indices/colombia-indices',
    '哥斯达黎加': '/indices/costa-rica-indices',
    '土耳其': '/indices/turkey-indices',
    '坦桑尼亚': '/indices/tanzania-indices',
    '埃及': '/indices/egypt-indices',
    '塞尔维亚': '/indices/serbia-indices',
    '塞浦路斯': '/indices/cyprus-indices',
    '墨西哥': '/indices/mexico-indices',
    '奥地利': '/indices/austria-indices',
    '委内瑞拉': '/indices/venezuela-indices',
    '孟加拉国': '/indices/bangladesh-indices',
    '尼日利亚': '/indices/nigeria-indices',
    '巴勒斯坦领土': '/indices/palestine-indices',
    '巴基斯坦': '/indices/pakistan-indices',
    '巴林': '/indices/bahrain-indices',
    '巴西': '/indices/brazil-indices',
    '希腊': '/indices/greece-indices',
    '德国': '/indices/germany-indices',
    '意大利': '/indices/italy-indices',
    '拉脱维亚': '/indices/latvia-indices',
    '挪威': '/indices/norway-indices',
    '捷克': '/indices/czech-republic-indices',
    '摩洛哥': '/indices/morocco-indices',
    '斯洛伐克': '/indices/slovakia-indices',
    '斯洛文尼亚': '/indices/slovenia-indices',
    '斯里兰卡': '/indices/sri-lanka-indices',
    '新加坡': '/indices/singapore-indices',
    '新西兰': '/indices/new-zealand-indices',
    '日本': '/indices/japan-indices',
    '智利': '/indices/chile-indices',
    '比利时': '/indices/belgium-indices',
    '毛里求斯': '/indices/mauritius-indices',
    '沙特阿拉伯': '/indices/saudi-arabia-indices',
    '法国': '/indices/france-indices',
    '波兰': '/indices/poland-indices',
    '波黑': '/indices/bosnia-indices',
    '泰国': '/indices/thailand-indices',
    '津巴布韦': '/indices/zimbabwe-indices',
    '澳大利亚': '/indices/australia-indices',
    '爱尔兰': '/indices/ireland-indices',
    '爱沙尼亚': '/indices/estonia-indices',
    '牙买加': '/indices/jamaica-indices',
    '瑞典': '/indices/sweden-indices',
    '瑞士': '/indices/switzerland-indices',
    '科威特': '/indices/kuwaiti-indices',
    '科特迪亚': '/indices/ivory-coast-indices',
    '秘鲁': '/indices/peru-indices',
    '突尼斯': '/indices/tunisia-indices',
    '立陶宛': '/indices/lithuania-indices',
    '约旦': '/indices/jordan-indices',
    '纳米比亚': '/indices/namibia-indices',
    '罗马尼亚': '/indices/romania-indices',
    '美国': '/indices/usa-indices',
    '肯尼亚': '/indices/kenya-indices',
    '芬兰': '/indices/finland-indices',
    '英国': '/indices/uk-indices',
    '荷兰': '/indices/netherlands-indices',
    '菲律宾': '/indices/philippines-indices',
    '葡萄牙': '/indices/portugal-indices',
    '蒙古': '/indices/mongolia-indices',
    '西班牙': '/indices/spain-indices',
    '赞比亚': '/indices/zambia-indices',
    '越南': '/indices/vietnam-indices',
    '阿拉伯联合酋长国': '/indices/dubai-indices',
    '阿曼': '/indices/oman-indices',
    '阿根廷': '/indices/argentina-indices',
    '韩国': '/indices/south-korea-indices',
    '香港': '/indices/hong-kong-indices',
    '马尔他': '/indices/malta-indices',
    '马拉维': '/indices/malawi-indices',
    '马来西亚': '/indices/malaysia-indices',
    '黎巴嫩': '/indices/lebanon-indices',
    '黑山': '/indices/montenegro-indices'}
    """
    url = "https://cn.investing.com/indices/"
    res = requests.post(url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    name_url_option_list = soup.find("select", attrs={"name": "country"}).find_all(
        "option"
    )[
        1:
    ]  # 去掉-所有国家及地区
    url_list = [item["value"] for item in name_url_option_list]
    name_list = [item.get_text() for item in name_url_option_list]
    name_code_map_dict = {}
    name_code_map_dict.update(zip(name_list, url_list))
    return name_code_map_dict


def index_investing_global_country_name_url(country: str = "中国") -> dict:
    """
    参考网页: https://cn.investing.com/indices/
    获取选择国家对应的: 主要指数, 主要行业, 附加指数, 其他指数
    :param country: str 中文国家名称, 对应 get_global_country_name_url 函数返回的国家名称
    :return: dict
     {'上证指数': '/indices/shanghai-composite', '深证成指': '/indices/szse-component', '上证100': '/indices/sse-100',
     'A股指数': '/indices/shanghai-se-a-share', '中信标普300': '/indices/s-p-citic300', '中信标普50': '/indices/s-p-citic50',
     '富时中国A50指数': '/indices/ftse-china-a50', '上证消费': '/indices/sse-consumer-staples',
     '上证信息': '/indices/sse-information-technology', '上证公用': '/indices/sse-utilities',
     '上证医药': '/indices/sse-health-care', '上证材料': '/indices/sse-materials',
     '上证可选': '/indices/sse-consumer-discretionary', '上证商品': '/indices/sse-commodity-equity',
     '上证工业': '/indices/sse-industrials', '上证新兴': '/indices/sse-emerging-industries',
     '上证电信': '/indices/sse-telecommunication-services', '综合指数': '/indices/sse-misc-sub', '上证能源': '/indices/sse-energy',
     '上证资源': '/indices/sse-natural-resource', '上证金融': '/indices/sse-financials',
     '上证银行': '/indices/sse-banks-total-return', '餐饮指数': '/indices/szse-hotel---catering',
     'IT指数': '/indices/szse-information-technology', '创业板50': '/indices/szse-chinext-50',
     '制造指数': '/indices/szse-manufacturing', '商务指数': '/indices/szse-business-service',
     '富时中国A600一般零售商': '/indices/ftse-china-general-retailers',
     '富时中国A600产油设备 - 相关服务和分销': '/indices/ftse-china-oil-eq-ser.---dist.',
     '富时中国A600人寿保险': '/indices/ftse-china-life-insurance', '富时中国A600公用事业': '/indices/ftse-china-utilities',
     '富时中国A600天然气、水和多用途设施': '/indices/ftse-china-gas---water-utilities', '富时中国A600媒体': '/indices/ftse-china-media',
     '富时中国A600房地产投资与服务': '/indices/ftse-china-reit---services', '富时中国A600旅游和休闲': '/indices/ftse-china-travel---leisure',
     '富时中国A600电信服务': '/indices/ftse-china-telecommunications', '富时中国A600电力': '/indices/ftse-china-electricity',
     '富时中国A600科技': '/indices/ftse-china-technology', '富时中国A600科技硬件和设备': '/indices/ftse-china-tech-hardware---eq',
     '富时中国A600移动电信服务': '/indices/ftse-china-mobile', '富时中国A600软件和计算机服务': '/indices/ftse-china-soft.---com.-services',
     '富时中国A600金融': '/indices/ftse-china-financials', '富时中国A600银行': '/indices/ftse-china-banks',
     '富时中国蓝筹价值100': '/indices/ftse-china-blue-chip-value-100', '建筑指数': '/indices/szse-construction',
     '地产指数': '/indices/sse-property-sub', '批零指数': '/indices/szse-wholesale---retail', '文化指数': '/indices/szse-media',
     '新综指': '/indices/sse-new-comp', '深证上游': '/indices/szse-upstream-industry',
     '深证下游': '/indices/szse-downstream-industry', '深证中游': '/indices/szse-midstream-industry',
     '深证消费': '/indices/szse-consumer-staples', '深证信息': '/indices/szse-technology', '深证公用': '/indices/szse-utilities',
     '深证农业': '/indices/szse-agriculture', '深医药50': '/indices/szse-health-care-50', '深证医药': '/indices/szse-health-care',
     '深证材料': '/indices/szse-materials', '深证可选': '/indices/szse-consumer-discretionary',
     '深证大宗': '/indices/szse-commodities-producer', '深证央企': '/indices/szse-central-company',
     '深证工业': '/indices/szse-industrials', '深证文化': '/indices/szse-culture',
     '深证民营': '/indices/szse-individual-businesses-price', '深消费50': '/indices/szse-consumer-50',
     '深证环保': '/indices/szse-environmental-protection', '深证电信': '/indices/szse-telecom',
     '深证绩效': '/indices/szse-performance', '深证能源': '/indices/szse-energy', '深证时钟': '/indices/szse-investment-clock',
     '深证龙头': '/indices/szse-industry-top', '深证装备': '/indices/szse-equipment-manufacturing',
     '深证责任': '/indices/szse-responsibility-price', '深证金融': '/indices/szse-financials',
     '深防御50': '/indices/szse-defensive-50', '科研指数': '/indices/szse-research---development',
     '综企指数': '/indices/szse-conglomerates', '运输指数': '/indices/szse-transportation', '采矿指数': '/indices/szse-mining',
     '5年信用': '/indices/sse-5-year-credit-bond', '企债指数': '/indices/shanghai-se-corporate-bond',
     '沪企债30': '/indices/sse-cb-30', '信用100': '/indices/sse-credit-bond-100', '沪公司债': '/indices/sse-enterprise-bond',
     '上证转债': '/indices/sse-convertible-bond', '国债指数': '/indices/shanghai-se-treasury-bond',
     '治理指数': '/indices/sse-corporate-governance', '沪投资品': '/indices/sse-investment-commodity',
     '沪消费品': '/indices/sse-consumer-commodity', '富时中国A600一般工业行业指数': '/indices/ftse-china-600-general-industrials',
     '富时中国A600一般金融行业指数': '/indices/ftse-china-600-financial-services',
     '富时中国A600个人消费品行业指数': '/indices/ftse-china-a-600-personal-goods',
     '富时中国A600制药和生物科技行业指数': '/indices/ftse-china-600-pharma---biotech',
     '富时中国A600化工制品行业指数': '/indices/ftse-china-a-600-chemicals',
     '富时中国A600卫生保健行业指数': '/indices/ftse-china-a-600--health-care',
     '富时中国A600基础材料行业指数': '/indices/ftse-china-a-600-basic-materials',
     '富时中国A600家庭用品行业指数': '/indices/ft-china-600-hous.goods---textiles',
     '富时中国A600家庭用品及住宅建筑行业指数': '/indices/ftse-china-a-600-household-goods',
     '富时中国A600工业行业指数': '/indices/ftse-china-a-600-industrials',
     '富时中国A600工业工程行业指数': '/indices/ftse-china-600-ind.-engineering',
     '富时中国A600工业金属和矿业行业指数': '/indices/ftse-china-a-600-industrial-metal',
     '富时中国A600建筑和材料行业指数': '/indices/ft-china-600-cons.---materials',
     '富时中国A600替代能源行业指数': '/indices/ftse-china-a-600-altenative-energy',
     '富时中国A600林业和造纸行业指数': '/indices/ftse-china-a-600-forestry---paper',
     '富时中国A600汽车和零件行业指数': '/indices/ftse-china-600-automobile---parts',
     '富时中国A600消费服务行业指数': '/indices/ftse-china-a-600-consumer-services',
     '富时中国A600生活消费品行业指数': '/indices/ftse-china-a-600-consumer-goods',
     '富时中国A600电子和电器设备行业指数': '/indices/ftse-china-600-elec.---elec.eq',
     '富时中国A600石油和天然气行业指数': '/indices/ftse-china-a-600-oil---gas',
     '富时中国A600石油和天然气生产商行业指数': '/indices/ftse-china-600-oil---gas-producers',
     '富时中国A600航天航空和国航行业指数': '/indices/ftse-china-600-aerospace---defence',
     '富时中国A600辅助服务行业指数': '/indices/ftse-china-a-600-support-services',
     '富时中国A600运输行业指数': '/indices/ftse-china-a-600-industrial-trans.',
     '富时中国A600采矿行业指数': '/indices/ftse-china-a-600-mining',
     '富时中国A600食品和药物零售行业指数': '/indices/ftse-china-600-food---drug-ret.',
     '富时中国A600食品生产商行业指数': '/indices/ftse-china-a-600-food-producers',
     '富时中国A600饮料行业指数': '/indices/ftse-china-a-600-beverages', '上证150': '/indices/sse-150',
     '180运输': '/indices/sse-180-transportation', '180价值': '/indices/sse180-value', '180低贝': '/indices/sse-180-low-beta',
     '180治理': '/indices/sse-180-corporate-governance', '180动态': '/indices/sse-180-dynamic',
     '180基建': '/indices/sse-180-infrastructure', '180基本': '/indices/sse-180-fundamental-weighted',
     '180成长': '/indices/sse180-growth', '上证180': '/indices/shanghai-se-180',
     '180波动': '/indices/sse-180-volatility-weighted', '180R价值': '/indices/sse180-relative-value',
     '180R成长': '/indices/sse180-relative-growth', '180稳定': '/indices/sse-180-stability',
     '180等权': '/indices/sse-180-equal-weight', '180红利': '/indices/sse-180-dividend',
     '180资源': '/indices/sse-180-natural-resource', '180金融': '/indices/shanghai-se-180-financial',
     '180高贝': '/indices/sse-180-high-beta', '380消费': '/indices/sse-380-consumer-staples',
     '380价值': '/indices/sse-380-value', '380低贝': '/indices/sse-380-low-beta',
     '380信息': '/indices/sse-380-information-technology', '380公用': '/indices/sse-380-utilities',
     '380动态': '/indices/sse-380-dynamic', '380医药': '/indices/sse-380-health-care',
     '380材料': '/indices/sse-380-materials', '380可选': '/indices/sse-380-consumer-discretionary',
     '380基本': '/indices/sse-380-fundamental-weighted', '380工业': '/indices/sse-380-industrials',
     '380成长': '/indices/sse-380-growth', '上证380': '/indices/sse-380', '380波动': '/indices/sse-380-volatility-weighted',
     '380电信': '/indices/sse-380-telecommunication-services', '380R价值': '/indices/sse-380-relative-value',
     '380R成长': '/indices/sse-380-relative-growth', '380稳定': '/indices/sse-380-stability',
     '380等权': '/indices/sse-380-equal-weight', '380红利': '/indices/sse-380-dividend', '380能源': '/indices/sse-380-energy',
     '380金融': '/indices/sse-380-financials', '380高贝': '/indices/sse-380-high-beta',
     '50基本': '/indices/sse-50-fundamental-weighted', '上证50': '/indices/shanghai-se-50',
     '50等权': '/indices/sse-50-equal-weight', 'B股指数': '/indices/shanghai-se-b-share',
     '上证上游': '/indices/sse-upstream-industry', '上证下游': '/indices/sse-downstream-industry',
     '中型综指': '/indices/sse-medium-enterprise-composite', '上证央企': '/indices/sse-central-state-owned-enterprises',
     '上证中小': '/indices/sse-mid-small-cap', '上证中游': '/indices/sse-midstream-industry', '上证中盘': '/indices/sse-midcap',
     '消费等权': '/indices/sse-consumer-staples-equal-weight', '优势制造': '/indices/sse-select-manufacturing-industries',
     '优势消费': '/indices/sse-select-consumption-industries', '优势资源': '/indices/sse-select-resources-industries',
     '信息等权': '/indices/sse-information-technology-equal-we', '全指价值': '/indices/sse-large-mid-small-cap-value',
     '全指成长': '/indices/sse-large-mid-small-cap-growth', '全R价值': '/indices/sse-large-mid-small-cap-relative-va',
     '全R成长': '/indices/sse-large-mid-small-cap-relative-gr', '公用等权': '/indices/sse-utilities-equal-weight',
     '公用指数': '/indices/sse-utility-sub', '农业主题': '/indices/sse-agriculture-theme',
     '医药主题': '/indices/sse-health-care-theme', '医药等权': '/indices/sse-health-care-equal-weight',
     '材料等权': '/indices/sse-materials-equal-weight', '持续产业': '/indices/sse-sustainable-development-industr',
     '可选等权': '/indices/sse-consumer-discretionary-equal-we', '上证周期': '/indices/sse-cyclical-industry-50',
     '商业指数': '/indices/sse-commercial-sub', '上证国企': '/indices/sse-state-owned-enterprises-100',
     '上国红利': '/indices/sse-state-owned-enterprises-dividen', '上证地企': '/indices/sse-local-state-owned-enterprises-5',
     '上证F200': '/indices/ssef-200', '上证F300': '/indices/ssef-300', '上证F500': '/indices/ssef-500',
     '上证全指': '/indices/sse-large-mid-small-cap', '上证小盘': '/indices/sse-smallcap', '工业指数': '/indices/sse-industrial-sub',
     '工业等权': '/indices/sse-industrials-equal-weight', '市值百强': '/indices/sse-market-value-top-100',
     '上证民企': '/indices/sse-private-owned-enterprises-50', '上民红利': '/indices/sse-private-owned-enterprises-divid',
     '上证沪企': '/indices/sse-shanghai-enterprises', '上证流通': '/indices/sse-free-float',
     '上证海外': '/indices/sse-overseas-listing-a-share', '消费50': '/indices/sse-consumer-50',
     '消费80': '/indices/sse-consumer-80', '消费领先': '/indices/sse-leading-consumption-and-service',
     '上证环保': '/indices/sse-environmental-protection-indust', '电信等权': '/indices/sse-telecommunication-services-equa',
     '责任指数': '/indices/sse-social-responsibility', '红利指数': '/indices/sse-dividend',
     '能源等权': '/indices/sse-energy-equal-weight', '沪财中小': '/indices/sse-wealth-mid-small',
     '资源50': '/indices/sse-resource-50', '超大盘': '/indices/sse-mega-cap', '金融等权': '/indices/sse-financials-equal-weight',
     '非周期': '/indices/sse-non-cyclical-industry-100', '上证高新': '/indices/sse-high-and-new-technology-enterpr',
     '高端装备': '/indices/sse-high-end-equipment-manufacturin', '上证龙头': '/indices/sse-industry-top',
     '中信标普企业债指数': '/indices/citic-corp-bond', '中创EW': '/indices/szse-sme-chinext-100-equal-weighted',
     '中创低波': '/indices/szse-500-low-volatility', '中创高贝': '/indices/szse-500-high-beta',
     '中创高新': '/indices/szse-sme-chinext-hnte', '中小低波': '/indices/szse-sme-low-volatility',
     '中小高贝': '/indices/szse-sme-high-beta', '中创100': '/indices/sme-chinext-100-price',
     '中创100R': '/indices/sme-chinext-100-trn', '中创400': '/indices/sme-chinext-400',
     '中创500': '/indices/sme-chinext-500', '中小基础': '/indices/szse-sme-prime-market',
     '中小价值': '/indices/sme-300-value-price', '中小成长': '/indices/sme-300-growth-price',
     '中小300': '/indices/szse-sme-300-price', '中创价值': '/indices/sme-chinext-value',
     '中创成长': '/indices/sme-chinext-growth', 'SME创新': '/indices/szse-sme-price',
     '中小新兴': '/indices/szse-sme-strategic-emerging-industr', '中小板R': '/indices/szse-sme-return',
     '中小绩效': '/indices/szse-sme-performance-weighted', '中小治理': '/indices/szse-sme-corp-governance',
     '中小板EW': '/indices/szse-sme-equal-weight', '中小红利': '/indices/szse-sme-dividend',
     '中小板综': '/indices/szse-sme-composite', '中小责任': '/indices/szse-sme-csr', '创业300': '/indices/szse-chinext-300',
     '创业板V': '/indices/chinext-300-value', '创业板G': '/indices/chinext-300-growth',
     '创业基础': '/indices/szse-chinext-prime-market', '创业新兴': '/indices/szse-chinext-strategic-emerging-ind',
     '创业板指': '/indices/chinext-price', '创业板R': '/indices/chinext-return', '创业板EW': '/indices/szse-chinext-equal-weight',
     '创业板综': '/indices/chinext-composite', '科技100': '/indices/sme-chinext-tec-100-price',
     '富时Shariah中国指数': '/indices/ftse-shariah-china', '富时中国H股指数': '/indices/ftse-china-h-share',
     '富时中国指数': '/indices/ftse-china', '富时价值股份中国指数': '/indices/ftse-value-stocks-china',
     '富时大中华指数': '/indices/ftse-greater-china', '富时大中华指数全指': '/indices/ftse-greater-china-all-cap',
     '沪深300': '/indices/csi300', '深报指数': '/indices/szse-press', '深报综指': '/indices/szse-press-composite',
     '1000价值': '/indices/szse-1000-value', '1000成长': '/indices/szse-1000-growth', '深证1000': '/indices/szse-1000',
     '100低波': '/indices/szse-100-low-volatility', '深证100': '/indices/szse-100-price', '深证100R': '/indices/szse-100',
     '深100EW': '/indices/szse-100-equal-weight', '100绩效': '/indices/szse-100-performance-weighted',
     '深证200': '/indices/szse-200', '深证价值': '/indices/szse-300-value-price', '深证300': '/indices/szse-300-price',
     '深证低波': '/indices/szse-300-low-volatility', '深证成长': '/indices/szse-300-growth-price',
     '深证300R': '/indices/szse-300', '深300EW': '/indices/szse-300-equal-weight',
     '300绩效': '/indices/szse-300-performance-weighted', '深证高贝': '/indices/szse-300-high-beta',
     '700价值': '/indices/szse-700-value', '700成长': '/indices/szse-700-growth', '深证700': '/indices/szse-700',
     '深证A指': '/indices/szse-a-share', '深证B指': '/indices/szse-b-share', '深证GDP': '/indices/szse-gdp-100',
     '深证创新': '/indices/szse-innovation-price', '深周期50': '/indices/szse-cyclical-50', '深证F120': '/indices/szfi-120',
     '深证F200': '/indices/szfi-200', '深证F60': '/indices/szfi-60', '成份B指': '/indices/szse-b-share-sub',
     '深成指R': '/indices/szse-a-share-sub', '深成指EW': '/indices/szse-component-equal-weighted',
     '成长40': '/indices/szse-growth-price', '深证新兴': '/indices/szse-strategic-emerging-industries',
     '新指数': '/indices/szse-new', '深证治理': '/indices/szse-corp-governance-price', 'TMT50': '/indices/szse-tmt50-price',
     '深证红利': '/indices/szse-dividend-price', '深证综指': '/indices/szse-composite'}
    """
    pd.set_option("mode.chained_assignment", None)
    name_url_dict = _get_global_country_name_url()
    name_code_dict = _get_global_index_country_name_url()
    url = f"https://cn.investing.com{name_url_dict[country]}?&majorIndices=on&primarySectors=on&additionalIndices=on&otherIndices=on"
    res = requests.post(url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    url_list = [
        item.find("a")["href"] for item in soup.find_all(attrs={"class": "plusIconTd"})
    ]
    name_list = [
        item.find("a").get_text()
        for item in soup.find_all(attrs={"class": "plusIconTd"})
    ]
    name_code_map_dict = {}
    name_code_map_dict.update(zip(name_list, url_list))

    url = "https://cn.investing.com/indices/global-indices"
    params = {
        "majorIndices": "on",
        "primarySectors": "on",
        "bonds": "on",
        "additionalIndices": "on",
        "otherIndices": "on",
        "c_id": name_code_dict[country],
    }
    r = requests.get(url, params=params, headers=short_headers)
    data_text = r.text
    soup = BeautifulSoup(data_text, "lxml")
    soup_list = soup.find("table", attrs={"id": "cr_12"}).find_all("a")
    global_index_url = [item["href"] for item in soup_list]
    global_index_name = [item["title"] for item in soup_list]
    name_code_map_dict.update(zip(global_index_name, global_index_url))
    return name_code_map_dict


def index_investing_global(
    country: str = "美国",
    index_name: str = "纳斯达克100",
    period: str = "每日",
    start_date: str = "20100101",
    end_date: str = "20211031",
) -> pd.DataFrame:
    """
    具体国家的具体指数的从 start_date 到 end_date 期间的数据
    :param country: 对应函数中的国家名称
    :type country: str
    :param index_name: 对应函数中的指数名称
    :type index_name: str
    :param period: choice of {"每日", "每周", "每月"}
    :type period: str
    :param start_date: '2000-01-01', 注意格式
    :type start_date: str
    :param end_date: '2019-10-17', 注意格式
    :type end_date: str
    :return: 指定参数的数据
    :rtype: pandas.DataFrame
    """
    start_date = "/".join([start_date[:4], start_date[4:6], start_date[6:]])
    end_date = "/".join([end_date[:4], end_date[4:6], end_date[6:]])
    period_map = {"每日": "Daily", "每周": "Weekly", "每月": "Monthly"}
    name_code_dict = index_investing_global_country_name_url(country)
    temp_url = f"https://cn.investing.com/{name_code_dict[index_name]}-historical-data"
    res = requests.post(temp_url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    title = soup.find("h2", attrs={"class": "float_lang_base_1"}).get_text()
    res = requests.post(temp_url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    data = soup.find_all(text=re.compile("window.histDataExcessInfo"))[0].strip()
    para_data = re.findall(r"\d+", data)
    payload = {
        "curr_id": para_data[0],
        "smlID": para_data[1],
        "header": title,
        "st_date": start_date,
        "end_date": end_date,
        "interval_sec": period_map[period],
        "sort_col": "date",
        "sort_ord": "DESC",
        "action": "historical_data",
    }
    url = "https://cn.investing.com/instruments/HistoricalDataAjax"
    res = requests.post(url, data=payload, headers=long_headers)
    df_data = pd.read_html(res.text)[0]
    if period == "每月":
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月")
    else:
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月%d日")
    if any(df_data["交易量"].astype(str).str.contains("-")):
        df_data["交易量"][df_data["交易量"].str.contains("-")] = df_data["交易量"][
            df_data["交易量"].str.contains("-")
        ].replace("-", 0)
    if any(df_data["交易量"].astype(str).str.contains("B")):
        df_data["交易量"][df_data["交易量"].str.contains("B").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("B").fillna(False)]
            .str.replace("B", "")
            .str.replace(",", "")
            .astype(float)
            * 1000000000
        )
    if any(df_data["交易量"].astype(str).str.contains("M")):
        df_data["交易量"][df_data["交易量"].str.contains("M").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("M").fillna(False)]
            .str.replace("M", "")
            .str.replace(",", "")
            .astype(float)
            * 1000000
        )
    if any(df_data["交易量"].astype(str).str.contains("K")):
        df_data["交易量"][df_data["交易量"].str.contains("K").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("K").fillna(False)]
            .str.replace("K", "")
            .str.replace(",", "")
            .astype(float)
            * 1000
        )
    df_data["交易量"] = df_data["交易量"].astype(float)
    df_data = df_data[["收盘", "开盘", "高", "低", "交易量"]]
    df_data = df_data.astype(float)
    df_data.sort_index(inplace=True)
    df_data.reset_index(inplace=True)
    df_data['日期'] = pd.to_datetime(df_data['日期']).dt.date
    return df_data


def index_investing_global_from_url(
    url: str = "https://www.investing.com/indices/ftse-epra-nareit-eurozone",
    period: str = "每日",
    start_date: str = "20000101",
    end_date: str = "20210909",
) -> pd.DataFrame:
    """
    获得具体指数的从 start_date 到 end_date 期间的数据
    https://www.investing.com/indices/ftse-epra-nareit-eurozone
    :param url: 具体数据链接
    :type url: str
    :param period: choice of {"每日", "每周", "每月"}
    :type period: str
    :param start_date: '2000-01-01', 注意格式
    :type start_date: str
    :param end_date: '2019-10-17', 注意格式
    :type end_date: str
    :return: 指定参数的数据
    :rtype: pandas.DataFrame
    """
    start_date = "/".join([start_date[:4], start_date[4:6], start_date[6:]])
    end_date = "/".join([end_date[:4], end_date[4:6], end_date[6:]])
    period_map = {"每日": "Daily", "每周": "Weekly", "每月": "Monthly"}
    url_name = url.split("/")[-1]
    temp_url = f"https://cn.investing.com/indices/{url_name}-historical-data"
    res = requests.post(temp_url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    title = soup.find("h2", attrs={"class": "float_lang_base_1"}).get_text()
    res = requests.post(temp_url, headers=short_headers)
    soup = BeautifulSoup(res.text, "lxml")
    data = soup.find_all(text=re.compile("window.histDataExcessInfo"))[0].strip()
    para_data = re.findall(r"\d+", data)
    payload = {
        "curr_id": para_data[0],
        "smlID": para_data[1],
        "header": title,
        "st_date": start_date,
        "end_date": end_date,
        "interval_sec": period_map[period],
        "sort_col": "date",
        "sort_ord": "DESC",
        "action": "historical_data",
    }
    url = "https://cn.investing.com/instruments/HistoricalDataAjax"
    res = requests.post(url, data=payload, headers=long_headers)
    df_data = pd.read_html(res.text)[0]
    if period == "每月":
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月")
    else:
        df_data.index = pd.to_datetime(df_data["日期"], format="%Y年%m月%d日")
    if any(df_data["交易量"].astype(str).str.contains("-")):
        df_data["交易量"][df_data["交易量"].str.contains("-")] = df_data["交易量"][
            df_data["交易量"].str.contains("-")
        ].replace("-", 0)
    if any(df_data["交易量"].astype(str).str.contains("B")):
        df_data["交易量"][df_data["交易量"].str.contains("B").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("B").fillna(False)]
            .str.replace("B", "")
            .str.replace(",", "")
            .astype(float)
            * 1000000000
        )
    if any(df_data["交易量"].astype(str).str.contains("M")):
        df_data["交易量"][df_data["交易量"].str.contains("M").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("M").fillna(False)]
            .str.replace("M", "")
            .str.replace(",", "")
            .astype(float)
            * 1000000
        )
    if any(df_data["交易量"].astype(str).str.contains("K")):
        df_data["交易量"][df_data["交易量"].str.contains("K").fillna(False)] = (
            df_data["交易量"][df_data["交易量"].str.contains("K").fillna(False)]
            .str.replace("K", "")
            .str.replace(",", "")
            .astype(float)
            * 1000
        )
    df_data["交易量"] = df_data["交易量"].astype(float)
    df_data = df_data[["收盘", "开盘", "高", "低", "交易量"]]
    df_data = df_data.astype(float)
    df_data.sort_index(inplace=True)
    df_data.reset_index(inplace=True)
    df_data['日期'] = pd.to_datetime(df_data['日期']).dt.date
    return df_data


if __name__ == "__main__":
    index_investing_global_from_url_df = index_investing_global_from_url(
        url="https://www.investing.com/indices/ftse-epra-nareit-hong-kong",
        period="每日",
        start_date="19900101",
        end_date="20210909",
    )
    print(index_investing_global_from_url_df)

    index_investing_global_country_name_url_dict = (
        index_investing_global_country_name_url("美国")
    )

    index_investing_global_df = index_investing_global(
        country="美国",
        index_name="纳斯达克100",
        period="每日",
        start_date="20000101",
        end_date="20210909",
    )
    print(index_investing_global_df)
